@@ -47,7 +47,6 @@ OC.L10N.register(
     "Invalid folder path" : "Ruta de carpeta inválida",
     "Folder not found" : "No se encontró la carpeta",
     "No favorites" : "No hay favoritos",
-    "Upload (max. %s)" : "Cargar (max. %s)",
     "Accept" : "Aceptar",
     "Reject" : "Rechazar",
     "Incoming ownership transfer from {user}" : "Solicitud de transferencia de propiedad entrante de {user}",
@@ -62,10 +61,6 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Se ha completado la transferencia de propiedad de {path} a {user}.",
     "in %s" : "en %s",
     "Transferred from %1$s on %2$s" : "Transfirió desde %1$s en %2$s",
-    "Files compatibility" : "Compatibilidad de archivos",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Permitir restringir los nombres de archivos para asegurar que los archivos se puedan sincronizar con todos los clientes. Por defecto, se permiten todos los nombres de archivos válidos en POSIX (por ejemplo, Linux o macOS).",
-    "Enforce Windows compatibility" : "Imponer la compatibilidad de Windows",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Esto bloqueará los nombres de archivos inválidos en sistemas Windows, tales como usar nombres reservados o caracteres especiales. Pero no impondrá la compatibilidad del uso de mayúsculas y minúsculas.",
     "File Management" : "Administración de Archivos",
     "Home" : "Inicio",
     "Target folder does not exist any more" : "La carpeta destino ya no existe",
@@ -92,6 +87,7 @@ OC.L10N.register(
     "Unknown date" : "Fecha desconocida",
     "Clear filter" : "Limpiar filtro",
     "Modified" : "Modificado",
+    "Search everywhere" : "Buscar en todas partes",
     "Type" : "Tipo",
     "Active filters" : "Filtros activos",
     "Remove filter" : "Quitar filtro",
@@ -99,15 +95,12 @@ OC.L10N.register(
     "Toggle selection for all files and folders" : "Alternar selección para todos los archivos y carpetas",
     "Name" : "Nombre",
     "Size" : "Tamaño",
-    "\"{displayName}\" batch action executed successfully" : "La acción en lote \"{displayName}\" se ejecutó exitosamente",
-    "\"{displayName}\" action failed" : "La acción \"{displayName}\" falló",
     "Actions" : "Acciones",
     "(selected)" : "(seleccionado)",
     "List of files and folders." : "Lista de archivos y carpetas.",
     "Column headers with buttons are sortable." : "Las columnas con botones en la cabecera son ordenables.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Esta lista no se muestra completamente por motivos de rendimiento. Los archivos se mostrarán a medida que navega por la lista.",
     "File not found" : "Archivo no encontrado",
-    "{count} selected" : "{count} seleccionados",
     "{usedQuotaByte} used" : "{usedQuotaByte} utilizados",
     "{used} of {quota} used" : "{used} de {quota} usados",
     "{relative}% used" : "{relative}% utilizado",
@@ -119,6 +112,8 @@ OC.L10N.register(
     "Create new folder" : "Crear nueva carpeta",
     "This name is already in use." : "Este nombre ya está en uso.",
     "Create" : "Crear",
+    "Refresh" : "Actualizar",
+    "Limit" : "Límite",
     "Fill template fields" : "Rellenar los campos de la plantilla",
     "Submit" : "Enviar",
     "Choose a file or folder to transfer" : "Elegir archivo o carpeta para transferir",
@@ -139,6 +134,29 @@ OC.L10N.register(
     "Adding the file extension \"{new}\" may render the file unreadable." : "Añadir la extensión de archivo \"{new}\" podría volver al archivo inaccesible.",
     "Select file or folder to link to" : "Seleccionar archivo o carpeta para enlazar.",
     "Choose {file}" : "Elegir {file}",
+    "Clipboard is not available" : "El portapapeles no está disponible",
+    "Files settings" : "Configuración de archivos",
+    "General" : "General",
+    "All files" : "Todos los archivos",
+    "Personal files" : "Archivos personales",
+    "Sort favorites first" : "Ordenar los favoritos primero",
+    "Sort folders before files" : "Ordenar carpetas antes que archivos",
+    "Appearance" : "Apariencia",
+    "Show hidden files" : "Mostrar archivos ocultos",
+    "Crop image previews" : "Recortar la previsualización de las imágenes",
+    "Additional settings" : "Configuraciones adicionales",
+    "WebDAV" : "WebDAV",
+    "WebDAV URL" : "WebDAV URL",
+    "Copy" : "Copiar",
+    "Keyboard shortcuts" : "Atajos del teclado",
+    "Rename" : "Renombrar",
+    "Delete" : "Borrar",
+    "Manage tags" : "Administrar etiquetas",
+    "Selection" : "Selección",
+    "Deselect all" : "Deseleccionar todo",
+    "Navigation" : "Navegación",
+    "View" : "Ver",
+    "Toggle grid view" : "Vista de cuadrícula",
     "Share" : "Compartir",
     "Shared by link" : "Compartido por liga",
     "Shared" : "Compartido",
@@ -150,36 +168,12 @@ OC.L10N.register(
     "Error during upload: {message}" : "Error durante la subida: {message}",
     "Error during upload, status code {status}" : "Error durante la carga, código de estado {status}",
     "Unknown error during upload" : "Error desconocido durante la carga",
-    "\"{displayName}\" action executed successfully" : "La acción \"{displayName}\" se ejecutó correctamente",
     "Loading current folder" : "Cargando la carpeta actual",
     "Retry" : "Reintentar",
     "No files in here" : "No hay archivos aquí",
     "Upload some content or sync with your devices!" : "¡Carga algún contenido o sincroniza con tus dispositivos!",
     "Go back" : "Regresar",
     "Views" : "Vistas",
-    "Files settings" : "Configuración de archivos",
-    "Your files" : "Sus archivos",
-    "Open in files" : "Abrir en archivos",
-    "File cannot be accessed" : "No se puede acceder al archivo",
-    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "El archivo no fue encontrado o no tiene permisos para verlo. Solicite al remitente que lo comparta.",
-    "Clipboard is not available" : "El portapapeles no está disponible",
-    "WebDAV URL copied to clipboard" : "WebDAV URL copiada al portapapeles",
-    "Sort favorites first" : "Ordenar los favoritos primero",
-    "Sort folders before files" : "Ordenar carpetas antes que archivos",
-    "Show hidden files" : "Mostrar archivos ocultos",
-    "Crop image previews" : "Recortar la previsualización de las imágenes",
-    "Enable the grid view" : "Habilitar la vista de cuadrícula",
-    "Enable folder tree" : "Habilitar el árbol de carpetas",
-    "Additional settings" : "Configuraciones adicionales",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "WebDAV URL",
-    "Copy to clipboard" : "Copiar al portapapeles",
-    "Use this address to access your Files via WebDAV" : "Use esta dirección para acceder a tus archivos vía WebDAV",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si ha habilitado 2FA, debe crear y utilizar una nueva contraseña de aplicación haciendo clic aquí.",
-    "Keyboard shortcuts" : "Atajos del teclado",
-    "Selection" : "Selección",
-    "Navigation" : "Navegación",
-    "View" : "Ver",
     "You" : "Usted",
     "Shared multiple times with different people" : "Compartido múltiples veces con diferentes personas",
     "Error while loading the file data" : "Error al cargar los datos del archivo",
@@ -187,12 +181,19 @@ OC.L10N.register(
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a favoritos",
     "Tags" : "Etiquetas",
+    "Your files" : "Sus archivos",
+    "Open in files" : "Abrir en archivos",
+    "File cannot be accessed" : "No se puede acceder al archivo",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "El archivo no fue encontrado o no tiene permisos para verlo. Solicite al remitente que lo comparta.",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Permitir restringir los nombres de archivos para asegurar que los archivos se puedan sincronizar con todos los clientes. Por defecto, se permiten todos los nombres de archivos válidos en POSIX (por ejemplo, Linux o macOS).",
+    "Files compatibility" : "Compatibilidad de archivos",
+    "Enforce Windows compatibility" : "Imponer la compatibilidad de Windows",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Esto bloqueará los nombres de archivos inválidos en sistemas Windows, tales como usar nombres reservados o caracteres especiales. Pero no impondrá la compatibilidad del uso de mayúsculas y minúsculas.",
     "Blank" : "Vacío",
     "Unable to create new file from template" : "No se ha podido crear un nuevo archivo desde la plantilla",
     "Pick a template for {name}" : "Elija una plantilla para {name}",
     "Create a new file with the selected template" : "Crear un nuevo archivo con la plantilla seleccionada",
     "Creating file" : "Creando el archivo",
-    "Deletion cancelled" : "Eliminación cancelada",
     "Leave this share" : "Dejar este recurso compartido",
     "Leave these shares" : "Dejar estos recursos compartidos",
     "Disconnect storage" : "Desconectar almacenamiento",
@@ -203,36 +204,31 @@ OC.L10N.register(
     "Delete files" : "Eliminar archivos",
     "Delete folder" : "Eliminar carpeta",
     "Delete folders" : "Eliminar carpetas",
-    "Delete" : "Borrar",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Está a punto de eliminar {count} elemento permanentemente.","Está a punto de eliminar {count} elementos permanentemente.","Está a punto de eliminar {count} elementos permanentemente."],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Está a punto de eliminar {count} elemento.","Está a punto de eliminar {count} elementos.","Está a punto de eliminar {count} elementos."],
     "Confirm deletion" : "Confirmar eliminación",
     "Cancel" : "Cancelar",
-    "Moving \"{source}\" to \"{destination}\" …" : "Moviendo \"{source}\" a \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Copiando \"{source}\" a \"{destination}\" …",
+    "Download" : "Descargar",
+    "Destination is not a folder" : "El destino no es una carpeta",
+    "This file/folder is already in that directory" : "Este archivo/carpeta ya está en ese directorio",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "No puede mover un archivo/carpeta a sí mismo o a una subcarpeta de sí mismo",
     "(copy)" : "(copiar)",
     "(copy %n)" : "(copiar %n)",
-    "Move cancelled" : "Movimiento cancelado",
     "A file or folder with that name already exists in this folder" : "Un archivo o carpeta con ese nombre ya existe en esta carpeta",
     "The files are locked" : "Los archivos están bloqueados",
     "The file does not exist anymore" : "El archivo ya no existe",
     "Choose destination" : "Elegir destino",
     "Copy to {target}" : "Copiar a {target}",
-    "Copy" : "Copiar",
     "Move to {target}" : "Mover a {target}",
     "Move" : "Mover",
     "Move or copy operation failed" : "La operación de mover o copiar falló",
     "Move or copy" : "Mover o copiar",
-    "Cancelled move or copy of \"{filename}\"." : "Se canceló la operación de mover o copiar de \"{filename}\".",
-    "Cancelled move or copy operation" : "Se canceló la operación de mover o copiar",
     "Open folder {displayName}" : "Abrir carpeta {displayName}",
     "Open in Files" : "Abrir en Archivos",
+    "Failed to redirect to client" : "Fallo al redirigir al cliente",
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "El archivo se abrirá ahora en tu dispositivo. Si esto no ocurre, por favor verifica que hayas instalado la aplicación de escritorio.",
     "Retry and close" : "Reintentar y cerrar",
-    "Failed to redirect to client" : "Fallo al redirigir al cliente",
-    "Rename" : "Renombrar",
-    "Open details" : "Abrir detalles",
+    "Details" : "Detalles",
     "View in folder" : "Ver en la carpeta",
     "Today" : "Hoy",
     "Last 7 days" : "Últimos 7 días",
@@ -245,9 +241,8 @@ OC.L10N.register(
     "PDFs" : "PDFs",
     "Folders" : "Carpetas",
     "Audio" : "Audio",
-    "Photos and images" : "Fotos e imágenes",
+    "Images" : "Imágenes",
     "Videos" : "Videos",
-    "New folder creation cancelled" : "Creación de nueva carpeta cancelada",
     "Created new folder \"{name}\"" : "Nueva carpeta \"{name}\" creada",
     "Unable to initialize the templates directory" : "No se ha podido iniciar la carpeta de plantillas",
     "Create templates folder" : "Crear la carpeta de plantillas",
@@ -268,8 +263,10 @@ OC.L10N.register(
     "Files moved successfully" : "Archivos movidos exitosamente",
     "Conflicts resolution skipped" : "Resolución de conflictos omitida",
     "Upload cancelled" : "Subida cancelada",
+    "Could not rename \"{oldName}\", it does not exist any more" : "No se pudo renombrar \"{oldName}\", ya no existe.",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nombre \"{newName}\" ya está en uso en la carpeta \"{dir}\". Por favor, elija un nombre diferente.",
+    "Could not rename \"{oldName}\"" : "No se pudo renombrar \"{oldName}\"",
     "This operation is forbidden" : "Esta operación está prohibida",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Esta carpeta no está disponible, por favor verfica las bitácoras o contacta al administrador",
     "Storage is temporarily not available" : "El almacenamiento no está disponible temporalmente ",
     "Unexpected error: {error}" : "Error inesperado: {error}",
     "_%n file_::_%n files_" : ["%n archivo","%n archivos","%n archivos"],
@@ -282,10 +279,7 @@ OC.L10N.register(
     "List of favorite files and folders." : "Lista de archivos y carpetas favoritos",
     "No favorites yet" : "Aún no hay favoritos",
     "Files and folders you mark as favorite will show up here" : "Los archivos y carpetas que marques como favoritos se mostrarán aquí. ",
-    "All files" : "Todos los archivos",
     "List of your files and folders." : "Lista de sus archivos y carpetas.",
-    "All folders" : "Todas las carpetas",
-    "Personal files" : "Archivos personales",
     "List of your files and folders that are not shared." : "Lista de sus archivos y carpetas que no están compartidos.",
     "No personal files found" : "No se encontraron archivos personales",
     "Files that are not shared will show up here." : "Aquí aparecerán los archivos y carpetas que no ha compartido.",
@@ -293,111 +287,32 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Lista de archivos y carpetas modificados recientemente.",
     "No recently modified files" : "No hay archivos modificados recientemente",
     "Files and folders you recently modified will show up here." : "Los archivos y carpetas que ha modificado recientemente aparecerán aquí.",
+    "Search" : "Buscar",
     "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
     "Select all" : "Seleccionar todo",
     "Upload too large" : "La carga es demasido grande",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que estás intentando cargar sobrepasan el tamaño máximo permitido para la carga de archivos en este servidor.",
-    "File could not be found" : "No fue posible encontrar el archivo",
-    "Download" : "Descargar",
-    "Show list view" : "Mostrar vista de lista",
-    "Show grid view" : "Mostrar vista de cuadrícula",
-    "Close" : "Cerrar",
-    "Could not create folder \"{dir}\"" : "No fue posible crear la carpeta \"{dir}\"",
-    "This will stop your current uploads." : "Esto detendrá las subidas en curso.",
-    "Upload cancelled." : "Carga cancelada.",
-    "Processing files …" : "Procesando archivos ...",
-    "…" : "...",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No fue posible cargar {filename} ya que es una carpeta o tiene un tamaño de 0 bytes",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "No tienes suficiente espacio disponible, Estás cargando {size1} pero sólo cuentas con {size2} disponible",
-    "Target folder \"{dir}\" does not exist any more" : "La carpeta destino \"{dir}\" ya no existe",
-    "An unknown error has occurred" : "Ha ocurrido un error desconocido",
-    "File could not be uploaded" : "No se ha podido subir el archivo",
-    "Uploading …" : "Cargando...",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Cargando … ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "No es posible subir este archivo",
-    "Error when assembling chunks, status code {status}" : "Se presentó un error al ensamblar los bloques, código de estatus {status}",
-    "Choose target folder" : "Elegir carpeta destino",
-    "Set reminder" : "Establecer recordatorio",
+    "Upload (max. %s)" : "Cargar (max. %s)",
+    "\"{displayName}\" batch action executed successfully" : "La acción en lote \"{displayName}\" se ejecutó exitosamente",
+    "\"{displayName}\" action failed" : "La acción \"{displayName}\" falló",
+    "\"{displayName}\" action executed successfully" : "La acción \"{displayName}\" se ejecutó correctamente",
+    "WebDAV URL copied to clipboard" : "WebDAV URL copiada al portapapeles",
+    "Enable the grid view" : "Habilitar la vista de cuadrícula",
+    "Enable folder tree" : "Habilitar el árbol de carpetas",
+    "Copy to clipboard" : "Copiar al portapapeles",
+    "Use this address to access your Files via WebDAV" : "Use esta dirección para acceder a tus archivos vía WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si ha habilitado 2FA, debe crear y utilizar una nueva contraseña de aplicación haciendo clic aquí.",
+    "Deletion cancelled" : "Eliminación cancelada",
     "Edit locally" : "Editar localmente",
-    "Open" : "Abrir",
-    "Could not load info for file \"{file}\"" : "No fue posible cargar información para el archivo \"{file}\"",
-    "Details" : "Detalles",
-    "Please select tag(s) to add to the selection" : "Seleccione la(s) etiqueta(s) para añadir a la selección",
-    "Apply tag(s) to selection" : "Aplicar etiqueta(s) a selección",
-    "Select directory \"{dirName}\"" : "Seleccione carpeta \"{dirName}\"",
-    "Select file \"{fileName}\"" : "Seleccione archivo \"{fileName}\"",
-    "Unable to determine date" : "No fue posible determinar la fecha",
-    "Could not move \"{file}\", target exists" : "No fue posible mover \"{file}\", el destino ya existe",
-    "Could not move \"{file}\"" : "No fue posible mover \"{file}\"",
-    "copy" : "copiar",
-    "Could not copy \"{file}\", target exists" : "No se pudo copiar \"{file}\", el destino ya existe",
-    "Could not copy \"{file}\"" : "No se pudo copiar \"{file}\"",
-    "Copied {origin} inside {destination}" : "{origin} fue copiado dentro de {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} y otros {nbfiles} archivos fueron copiados dentro de {destination}",
-    "{newName} already exists" : "{newName} ya existe",
-    "Could not rename \"{fileName}\", it does not exist any more" : "No fue posible renombrar \"{fileName}\", ya no existe",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nombre \"{targetName}\" ya está en uso en la carpeta \"{dir}\". Por favor elege un nombre diferete. ",
-    "Could not rename \"{fileName}\"" : "No fue posible renombrar \"{fileName}\"",
-    "Could not create file \"{file}\"" : "No fue posible crear el archivo \"{file}\"",
-    "Could not create file \"{file}\" because it already exists" : "No fue posible crear el archivo\"{file}\" porque ya existe",
-    "Could not create folder \"{dir}\" because it already exists" : "No fue posible crear la carpeta \"{dir}\" porque ya existe",
-    "Could not fetch file details \"{file}\"" : "No se pudo recuperar detalles de archivo \"{file}\"",
-    "Error deleting file \"{fileName}\"." : "Se presentó un error al borrar el archivo \"{fileName}\".",
-    "No search results in other folders for {tag}{filter}{endtag}" : "No se encontraron resultados en otras carpetas para  {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Ingrese al menos dos caracteres para buscar en otras carpetas",
-    "{dirs} and {files}" : "{dirs} y {files}",
-    "_including %n hidden_::_including %n hidden_" : ["incluyendo %n oculto","incluyendo %n ocultos","incluyendo %n ocultos"],
-    "You do not have permission to upload or create files here" : "No tiene permiso para crear o cargar archivos aquí",
-    "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Cargando %n archivos","Cargando %n archivos"],
-    "New" : "Nuevo",
-    "New file/folder menu" : "Menú de carpeta/archivo nuevo",
-    "Select file range" : "Seleccione rango de archivos",
-    "{used}%" : "{used}%",
-    "{used} used" : "{used} usados",
-    "\"{name}\" is an invalid file name." : "\"{name}\" es un nombre de archivo inválido. ",
-    "File name cannot be empty." : "El nombre de archivo no puede estar vacío.",
-    "\"/\" is not allowed inside a file name." : "No se permite el uso del caracter \"/\" en el nombre del archivo.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" es un tipo de archivo no permitido",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "El espacio de {owner} está lleno. ¡Los archivos ya no se pueden actualizar o sincronizar!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "¡La carpeta de grupo  \"{mountPoint}\" está llena, los archivos ya no pueden ser actualizados o sincronizados!.",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "¡El almacenamiento externo  \"{mountPoint}\" está lleno, los archivos ya no pueden ser actualizados o sincronizados!.",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Su almacenamiento está lleno. ¡No se puede actualizar o sincronizar ningún archivo más!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "El almacenamiento de {owner} está casi lleno ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "La carpeta de grupo \"{mountPoint}\" está casi llena ({usedSpacePercent}%)",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "El almacenamiento externo \"{mountPoint}\" está casi lleno ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Su almacenamiento está casi lleno ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["coincide \"{filter}\"","coinciden \"{filter}\"","coinciden \"{filter}\""],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Se ha copiado el enlace directo (sólo funciona para usuarios que tienen acceso a este archivo/carpeta)",
-    "Path" : "Ruta",
-    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
-    "Favorited" : "Marcado como favorito",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Copiar enlace directo (sólo funciona para usuarios que tienen acceso a este archivo/carpeta)",
-    "Upload file" : "Cargar archivo",
-    "Not favorited" : "No es un favorito",
-    "An error occurred while trying to update the tags" : "Se presentó un error al intentar actualizar la etiqueta",
-    "Storage informations" : "Informaciones de almacenamiento",
-    "Choose file" : "Elegir archivo",
-    "Go to the previous folder" : "Ir a la carpeta anterior",
-    "Open the files app settings" : "Abrir la configuración de la app Archivos",
-    "Unable to change the favourite state of the file" : "No se ha podido cambiar el estado de favorito del fichero",
-    "Edit file locally" : "Editar el archivo localmente",
-    "Edit online" : "Editar en línea",
-    "Create new templates folder" : "Crear nueva carpeta de plantillas",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} carpeta","{folderCount} carpetas","{folderCount} carpetas"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} archivo","{fileCount} archivos","{fileCount} archivos"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 archivo y {folderCount} carpeta","1 archivo y {folderCount} carpetas","1 archivo y {folderCount} carpetas"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} archivo y 1 carpeta","{fileCount} archivos y 1 carpeta","{fileCount} archivos y 1 carpeta"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} archivos y {folderCount} carpetas",
-    "List of favorites files and folders." : "Lista de archivos y carpetas favoritos.",
-    "Personal Files" : "Archivos personales",
-    "Text file" : "Archivo de texto",
-    "New text file.txt" : "Nuevo ArchivoDeTexto.txt",
-    "Favored" : "Favorecido",
-    "Favor" : "Favorecer",
-    "Not favored" : "No favorecido",
-    "Submitting fields…" : "Enviando campos...",
-    "Filter filenames…" : "Filtrar nombres de archivos..."
+    "Moving \"{source}\" to \"{destination}\" …" : "Moviendo \"{source}\" a \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Copiando \"{source}\" a \"{destination}\" …",
+    "Move cancelled" : "Movimiento cancelado",
+    "Cancelled move or copy of \"{filename}\"." : "Se canceló la operación de mover o copiar de \"{filename}\".",
+    "Cancelled move or copy operation" : "Se canceló la operación de mover o copiar",
+    "Open details" : "Abrir detalles",
+    "Photos and images" : "Fotos e imágenes",
+    "New folder creation cancelled" : "Creación de nueva carpeta cancelada",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Esta carpeta no está disponible, por favor verfica las bitácoras o contacta al administrador",
+    "All folders" : "Todas las carpetas"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
