@@ -32,14 +32,6 @@ OC.L10N.register(
     "Check password against the list of breached passwords from haveibeenpwned.com" : "Verifica la password con l'elenco di password compromesse di haveibeenpwnd.com",
     "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Questo controllo crea un hash della password e invia i primi 5 caratteri di questo hash alle API di haveibeenpwned.com per recuperare un elenco di tutti gli hash che iniziano con questi caratteri. Poi controlla se la password dell'istanza Nextcloud è presente nei risultati.",
     "Account password policies" : "Criteri per le password degli account",
-    "Share password policies" : "Condividi le policy sulle password",
-    "Unknown error" : "Errore sconosciuto",
-    "Minimal length has to be a non negative number" : "La lunghezza minima deve essere un numero positivo",
-    "History size has to be a non negative number" : "La dimensione della cronologia deve essere un numero positivo",
-    "Expiration days have to be a non negative number" : "I giorni di scadenza devono essere un numero positivo",
-    "Maximum login attempts have to be a non negative number" : "I massimi tentativi di accesso devono essere un numero positivo",
-    "Settings saved" : "Impostazioni salvate",
-    "Error while saving settings" : "Errore durante il salvataggio delle impostazioni",
-    "User password history" : "Cronologia della password degli utenti"
+    "Share password policies" : "Condividi le policy sulle password"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
