@@ -21,6 +21,9 @@ OC.L10N.register(
     "Mark selection as favorite" : "將選取範圍標記為最愛",
     "Add selection to favorites" : "新增選取範圍至最愛",
     "Remove selection from favorites" : "從最愛移除選取範圍",
+    "This name is already in use." : "此名稱已使用。",
+    "\"{char}\" is not allowed inside a filename." : "檔案名稱中不允許出現「{char}」",
+    "Invalid filename." : "無效的檔案名稱。",
     "Name of the album" : "相簿名稱",
     "Location of the album" : "相簿位置",
     "Back" : "返回",
@@ -173,7 +176,6 @@ OC.L10N.register(
     "Back to {folder}" : "回到 {folder}",
     "Share this folder" : "分享此資料夾",
     "Loading folders …" : "正在載入資料夾……",
-    "One of the source folders does not exists" : "其中一個來源資料夾不存在",
     "Add" : "新增"
 },
 "nplurals=1; plural=0;");
