@@ -19,7 +19,6 @@ OC.L10N.register(
     "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "提供有用的服务器信息，例如 CPU 负载、内存占用、硬盘占用、在线用户数等。",
     "Operating System:" : "操作系统：",
     "CPU:" : "CPU：",
-    "Unknown Processor" : "未知处理器",
     "Memory:" : "内存：",
     "Server time:" : "服务器时间：",
     "Uptime:" : "运行时长：",
@@ -79,11 +78,6 @@ OC.L10N.register(
     "Skip server update" : "跳过服务器更新",
     "To use an access token, please generate one then set it using the following command:" : "要使用一个访问令牌，请生成一个，然后使用以下命令设置它：",
     "Then pass the token with the \"NC-Token\" header when querying the above URL." : "然后在查询上述 URL 时传递带有 “NC-Token” 头的令牌。",
-    "Load average: {cpu} (last minute)" : "负载平均值： {cpu} （上一分钟）",
-    "DNS:" : "DNS：",
-    "Total users:" : "总用户：",
-    "24 hours:" : "24小时：",
-    "1 hour:" : "1小时：",
-    "5 mins:" : "5分钟："
+    "Unknown Processor" : "未知处理器"
 },
 "nplurals=1; plural=0;");
