@@ -56,7 +56,7 @@ OC.L10N.register(
     "Failed to delete tag" : "Etiket silinemedi",
     "Create or edit tags" : "Etiket ekle ya da düzenle",
     "Search for a tag to edit" : "Düzenlemek için bir etiket ara",
-    "Collaborative tags …" : "İş birlikli etiketler…",
+    "Collaborative tags …" : "İş birlikli etiketler…",
     "No tags to select" : "Seçilebilecek bir etiket yok",
     "Tag name" : "Etiket adı",
     "Tag level" : "Etiket düzeyi",
@@ -64,7 +64,7 @@ OC.L10N.register(
     "Update" : "Güncelle",
     "Delete" : "Sil",
     "Reset" : "Sıfırla",
-    "Loading …" : "Yükleniyor…",
+    "Loading …" : "Yükleniyor…",
     "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["Bir dosyada {tag1} eklenecek ve {tag2} kaldırılacak.","{count} dosyada {tag1} eklenecek ve {tag2} kaldırılacak."],
     "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["Bir dosyaya {tag} eklenecek.","{count} dosyaya {tag} eklenecek."],
     "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["Bir dosyadan {tag} kaldırılacak.","{count} dosyadan {tag} kaldırılacak."],
@@ -83,11 +83,11 @@ OC.L10N.register(
     "Choose tags for the selected files" : "Seçilmiş dosyalar için etiketleri seçin",
     "Cancel" : "İptal",
     "Apply" : "Uygula",
-    "Failed to load tags" : "Etiketler yüklenemedi",
     "Failed to load selected tags" : "Seçilmiş etiketler yüklenemedi",
+    "Failed to load tags" : "Etiketler yüklenemedi",
     "Failed to select tag" : "Seçilmiş etiket yüklenemedi",
     "System admin disabled tag creation. You can only use existing ones." : "Sistem yöneticisi etiket oluşturma iznini kaldırmış. Yalnızca var olan etiketleri kullanabilirsiniz.",
-    "Loading collaborative tags …" : "İş birlikli etiketler yükleniyor…",
+    "Loading collaborative tags …" : "İş birlikli etiketler yükleniyor…",
     "Search or create collaborative tags" : "İş birlikli etiket ara ya da ekle",
     "No tags to select, type to create a new tag" : "Seçilebilecek herhangi bir etiket yok. Yazarak yeni bir etiket ekleyin",
     "Unable to update setting" : "Ayar güncellenemedi",
@@ -109,9 +109,12 @@ OC.L10N.register(
     "Failed to load tags for file" : "Dosyanın etiketleri yüklenemedi",
     "Failed to set tag for file" : "Dosyanın etiketi ayarlanamadı",
     "Failed to delete tag for file" : "Dosyanın etiketi silinemedi",
+    "Collaborative tags …" : "İş birlikli etiketler…",
+    "Loading …" : "Yükleniyor…",
     "File tags modification canceled" : "Dosya etiket değişikliği iptal edildi",
     "Select or create tags to apply to all selected files" : "Tüm seçilmiş dosyalara uygulanacak etiketleri seçin ya da oluşturun",
     "Select tags to apply to all selected files" : "Tüm seçilmiş dosyalara uygulanacak etiketleri seçin",
-    "Apply changes" : "Değişiklikleri uygula"
+    "Apply changes" : "Değişiklikleri uygula",
+    "Loading collaborative tags …" : "İş birlikli etiketler yükleniyor…"
 },
 "nplurals=2; plural=(n > 1);");
