@@ -4,6 +4,7 @@ OC.L10N.register(
     "The file was uploaded" : "ຟາຍຖຶກອັບໂຫລດສຳເລັດ",
     "No file was uploaded" : "ບໍ່ມີການອັບໂຫລດຟາຍ",
     "Translate" : "ແປ",
+    "Copy link" : "ສຳເນົາລິງ",
     "Offline" : "ອັອບລາຍ",
     "Saving …" : "ກຳລັງບັນທຶກ",
     "Link" : "ລິງ",
@@ -12,8 +13,6 @@ OC.L10N.register(
     "Upload" : "ອັບໂຫຼດ",
     "Edit" : "ແກ້ໄຂ",
     "Details" : "ລາຍລະອຽດ",
-    "Info" : "ຂໍ້ມຸນ",
-    "Success" : "ຄວາມສໍາເລັດ",
-    "Warning" : "ແຈ້ງເຕືອນ"
+    "Choose" : "ເລືອກ"
 },
 "nplurals=1; plural=0;");
