@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "El tipu de ficheru ye inválidu",
     "An error occurred. Please contact your admin." : "Prodúxose un error. Ponte en contautu cola alministración.",
     "Invalid image" : "La imaxe ye inválida",
-    "No temporary profile picture available, try again" : "Nun hai nenguna semeya temporal pal perfil. Volvi tentalo",
-    "No crop data provided" : "Nun se fornió nengún datu de recorte",
-    "No valid crop data provided" : "Nun se fornió nengún datu de recorte válidu",
-    "Crop is not square" : "El recorte nun ye cuadráu",
     "State token does not match" : "El pase d'estáu nun concasa",
     "Invalid app password" : "La contraseña de l'aplicación ye inválida",
     "Could not complete login" : "Nun se pudo completar l'aniciu de la sesión",
@@ -50,6 +46,11 @@ OC.L10N.register(
     "No translation provider available" : "Nun hai nengún fornidor de traducciones disponible",
     "Could not detect language" : "Nun se pudo detectar la llingua",
     "Unable to translate" : "Nun ye posible traducir",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Pasos de la reparación:",
+    "Repair info:" : "Información de la reparación:",
+    "Repair warning:" : "Alvertencia de la reparación:",
+    "Repair error:" : "Error de la reparación:",
     "Nextcloud Server" : "Sirvidor de Nextcloud",
     "Some of your link shares have been removed" : "Quitáronse dalgunos enllaces de los elementos que compartiesti",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Pola mor d'un fallu de seguranza, tuviemos de quitar dalgunos enllaces compartíos. Consulta l'enllaz d'abaxo pa consiguir más información.",
@@ -57,11 +58,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Introduz la clave de la soscripción n'aplicación de sofitu p'aumentar la llende de cuentes. Esta aición tamién te concede tolos beneficios que Nextcloud Enterprise ufre, que son mui aconseyables pa compañes.",
     "Learn more ↗" : "Saber más ↗",
     "Preparing update" : "Tresnando l'anovamientu",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "Pasos de la reparación:",
-    "Repair info:" : "Información de la reparación:",
-    "Repair warning:" : "Alvertencia de la reparación:",
-    "Repair error:" : "Error de la reparación:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Usa l'anovador de la llinia de comandos porque l'anovamientu pel restolador ta desactiváu nel ficheru config.php.",
     "Turned on maintenance mode" : "Activóse'l mou de caltenimientu",
     "Turned off maintenance mode" : "Desactivóse'l mou de caltenimientu",
@@ -78,16 +74,8 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (incompatible)",
     "The following apps have been disabled: %s" : "Desactiváronse les aplicaciones siguientes: %s",
     "Already up to date" : "Yá s'anovó",
-    "Error occurred while checking server setup" : "Prodúxose un error mentanto se revisaba la configuración del sirvidor",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Pa consiguir más detalles, consulta la {linkstart}documentación ↗{linkend}.",
-    "unknown text" : "testu desconocíu",
-    "Hello world!" : "¡Hola, mundu!",
-    "sunny" : "soleyero",
-    "Hello {name}, the weather is {weather}" : "Nola {name}, ta {weather}",
-    "Hello {name}" : "Hola, {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Equí tienes los resultaos de la busca<script>alert(1)</script></strong>",
-    "new" : "novedá",
-    "_download %n file_::_download %n files_" : ["baxar %n ficheru","baxar %n ficheros"],
+    "Unknown" : "Desconocí­u",
+    "PNG image" : "Imaxe PNG",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "L'anovamientu ta en cursu. Ye posible qu'al colar d'esta páxina s'interrumpa'l procesu en dalgunos entornos.",
     "Update to {version}" : "Anovar a la versión {version}",
     "An error occurred." : "Prodúxose un error.",
@@ -109,7 +97,6 @@ OC.L10N.register(
     "Pick start date" : "Escoyer la data de comienzu",
     "Pick end date" : "Escoyer la data de fin",
     "Search in date range" : "Buscar nun intervalu de dates",
-    "Searching …" : "Buscando…",
     "Start typing to search" : "Comienza a escribir pa buscar",
     "No matching results" : "Nun hai nengún resultáu que concasare",
     "Today" : "Güei",
@@ -128,7 +115,6 @@ OC.L10N.register(
     "Load more results" : "Cargar más resultaos",
     "Search in" : "Buscar en",
     "Log in" : "Aniciar la sesión",
-    "Logging in …" : "Aniciando la sesión…",
     "Log in to {productName}" : "Aniciar la sesión en: {productName}",
     "Wrong login or password." : "El nomatu o la contraseña nun son correutos.",
     "This account is disabled" : "Esta cuenta ta desactivada",
@@ -136,8 +122,6 @@ OC.L10N.register(
     "Account name or email" : "Nome o direición de corréu de la cuenta",
     "Server side authentication failed!" : "¡L'autenticación de llau del sirvidor falló!",
     "Please contact your administrator." : "Ponte en contautu cola alministración.",
-    "Temporary error" : "Error temporal",
-    "Please try again." : "Volvi tentalo.",
     "An internal error occurred." : "Prodúxose un error internu.",
     "Please try again or contact your administrator." : "Volvi tentalo o ponte en contautu cola alministración.",
     "Password" : "Contraseña",
@@ -163,21 +147,16 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documentos, fueyes de cálculu y presentaciones collaboratives, fechos con Collabora Online.",
     "Distraction free note taking app." : "Una aplicación pa tomar notes ensin distraiciones.",
     "Recommended apps" : "Aplicaciones aconseyaes",
-    "Loading apps …" : "Cargando les aplicaciones…",
     "Could not fetch list of apps from the App Store." : "Nun se pudo dir en cata de la llista d'aplicaciones de la tienda d'aplicaciones",
     "App download or installation failed" : "La descarga o instalación d'aplicaciones falló",
     "Cannot install this app because it is not compatible" : "Nun se pue instalar esta aplicación porque nun ye compatible",
     "Cannot install this app" : "Nun se pue instalar esta aplicación",
     "Skip" : "Saltar",
-    "Installing apps …" : "Instalando les aplicaciones…",
     "Install recommended apps" : "Instalar les aplicaciones aconseyaes",
     "Avatar of {displayName}" : "Avatar de: {displayName}",
     "Settings menu" : "Menú de configuración",
-    "Loading your contacts …" : "Cargando los contautos…",
-    "Looking for {term} …" : "Buscando {term}…",
     "Search contacts" : "Buscar contautos",
     "Reset search" : "Reaniciar la busca",
-    "Search contacts …" : "Buscar contautos…",
     "Could not load your contacts" : "Nun se pudieron cargar los contautos",
     "No contacts found" : "Nun s'atopó nengun contautu",
     "Show all contacts" : "Amostar tolos contautos",
@@ -189,7 +168,6 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Prodúxose un error mentanto se buscaba «{type}»",
     "Search starts once you start typing and results may be reached with the arrow keys" : "La busca comienza namás que comiences a escribir y pues seleicionar los resultaos coles tecles del cursor",
     "Search for {name} only" : "Buscar «{name}» namás",
-    "Loading more results …" : "Cargando más resultaos…",
     "Forgot password?" : "¿Escaeciesti la contraseña?",
     "Back to login form" : "Volver al formulariu p'aniciar la sesión",
     "Back" : "Atrás",
@@ -211,7 +189,6 @@ OC.L10N.register(
     "Database tablespace" : "Espaciu de tabla de la base de datos",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Especifica'l númberu de puertu xunto col nome del agospiador (por exemplu, localhost:5432)",
     "Database host" : "Agospiador de la base de datos",
-    "Installing …" : "Instalando…",
     "Install" : "Instalar",
     "Need help?" : "¿Precises ayuda?",
     "See the documentation" : "Mira la documentación",
@@ -220,7 +197,6 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "El restolador nun ye compatible. Anuévalu o instala una versión compatible.",
     "Continue with this unsupported browser" : "SIguir con esti restolador incompatible",
     "Supported versions" : "Versiones compatibles",
-    "Search {types} …" : "Buscar «{types}»…",
     "Choose {file}" : "Escoyer «{file}»",
     "Choose" : "Escoyer",
     "Copy to {target}" : "Copiar a {target}",
@@ -240,7 +216,6 @@ OC.L10N.register(
     "(all selected)" : "(seleicionóse too)",
     "({count} selected)" : "({count} na seleición)",
     "Error loading file exists template" : "Hebo un error al cargar la plantía de ficheru esistente",
-    "Saving …" : "Guardando…",
     "seconds ago" : "hai segundos",
     "Connection to server lost" : "Perdióse la conexón col sirividor",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Hebo un problema al cargar la páxina, va volver cargase en %n segundu","Hebo un problema al cargar la páxina, va volver cargase en %n segundos"],
@@ -255,25 +230,16 @@ OC.L10N.register(
     "Type to search for existing projects" : "Escribi pa buscar proyeutos esistentes",
     "New in" : "Novedá en",
     "View changelog" : "Ver el rexistru de cambeos",
-    "No action available" : "Nun hai nenguna aición disponible",
-    "Error fetching contact actions" : "Hebo un error al dir en cata de les aiciones del contautu",
     "Close \"{dialogTitle}\" dialog" : "Zarrar el diálogu «{dialogTitle}»",
     "Email length is at max (255)" : "La llongura de la direición de corréu electrónicu ye la máxima (255)",
-    "Non-existing tag #{tag}" : "Etiqueta inesistente #{tag}",
-    "Restricted" : "Restrinxóse",
-    "Invisible" : "Invisible",
-    "Delete" : "Desaniciar",
-    "Rename" : "Renomar",
-    "Collaborative tags" : "Etiquetes collaboratives",
-    "No tags found" : "Nun s'atopó nenguna etiqueta",
     "Personal" : "Personal",
     "Accounts" : "Cuentes",
     "Admin" : "Alministración",
     "Help" : "Ayuda",
     "Access forbidden" : "Prohíbese l'accesu",
+    "Back to %s" : "Volver a «%s»",
     "Page not found" : "Nun s'atopó la páxina",
     "The page could not be found on the server or you may not be allowed to view it." : "Nun se pudo atopar la páxina nel sirvidor o ye posible que nun tengas permisu pa vela.",
-    "Back to %s" : "Volver a «%s»",
     "Too many requests" : "Milenta solicitúes",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Ficiéronse milenta solicitúes dende la to rede. Volvi tentalo dempués o ponte en contautu cola alministración si esti mensaxe ye un error.",
     "Error" : "Error",
@@ -348,29 +314,47 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia de %s ta nel mou de caltenimientu y pue talo un tiempu",
     "This page will refresh itself when the instance is available again." : "Esta páxina va anovase sola cuando la instancia vuelva tar disponible.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Ponte en contautu cola alministración del sistema si esti mensaxe sigue apaeciendo o apaez inesperadamente.",
-    "Currently open" : "Abierto",
-    "Login with username or email" : "Aniciar la sesión col nomatu o la direición de corréu electrónicu",
-    "Login with username" : "Aniciar la sesión col nomatu",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Charres, videollamaes, compartición de pantalla, reuniones en llinia y conferencies web; nel restolador y coles aplicaciones móviles.",
-    "You have not added any info yet" : "Nun amestesti nenguna información",
-    "{user} has not added any info yet" : "{user} nun amestó nenguna información",
-    "Error opening the user status modal, try hard refreshing the page" : "Hebo un error al abrir el diálogu modal del estáu d'usuariu, prueba a anovar la páxina",
-    "Edit Profile" : "Editar el perfil",
-    "The headline and about sections will show up here" : "Equí apaecen la testera y les seiciones d'información",
-    "Error loading message template: {error}" : "Hebo un error al cargar la plantía del mensaxe: {error}",
+    "Error occurred while checking server setup" : "Prodúxose un error mentanto se revisaba la configuración del sirvidor",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Pa consiguir más detalles, consulta la {linkstart}documentación ↗{linkend}.",
+    "unknown text" : "testu desconocíu",
+    "Hello world!" : "¡Hola, mundu!",
+    "sunny" : "soleyero",
+    "Hello {name}, the weather is {weather}" : "Nola {name}, ta {weather}",
+    "Hello {name}" : "Hola, {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Equí tienes los resultaos de la busca<script>alert(1)</script></strong>",
+    "new" : "novedá",
+    "_download %n file_::_download %n files_" : ["baxar %n ficheru","baxar %n ficheros"],
+    "Searching …" : "Buscando…",
+    "Logging in …" : "Aniciando la sesión…",
+    "Loading apps …" : "Cargando les aplicaciones…",
+    "Installing apps …" : "Instalando les aplicaciones…",
+    "Loading your contacts …" : "Cargando los contautos…",
+    "Looking for {term} …" : "Buscando {term}…",
+    "Search contacts …" : "Buscar contautos…",
+    "Loading more results …" : "Cargando más resultaos…",
+    "Search {types} …" : "Buscar «{types}»…",
+    "Saving …" : "Guardando…",
     "Very weak password" : "La contraseña ye mui poco segura",
     "Weak password" : "La contraseña ye poco segura",
     "So-so password" : "La contraseña ye normal",
     "Good password" : "La contraseña ye segura",
     "Strong password" : "La contraseña ye mui segura",
-    "Profile not found" : "Nun s'atopó'l perfil",
-    "The profile does not exist." : "El perfil nun esiste.",
+    "No action available" : "Nun hai nenguna aición disponible",
+    "Error fetching contact actions" : "Hebo un error al dir en cata de les aiciones del contautu",
+    "Non-existing tag #{tag}" : "Etiqueta inesistente #{tag}",
+    "Restricted" : "Restrinxóse",
+    "Invisible" : "Invisible",
+    "Delete" : "Desaniciar",
+    "Rename" : "Renomar",
+    "Collaborative tags" : "Etiquetes collaboratives",
+    "No tags found" : "Nun s'atopó nenguna etiqueta",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ye probable que'l to direutoriu de datos y los ficheros seyan accesibles dende internet porque'l ficheru .htaccess nun funciona.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pa consiguir más información tocante a cómo configurar afayadizamente'l sirvidor, mira la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentación</a>.",
     "Show password" : "Amosar la contraseña",
     "Toggle password visibility" : "Alternar la visibilidá de la contraseña",
     "Configure the database" : "Configurar la base de datos",
     "Only %s is available." : "Namás hai disponible %s.",
-    "Database account" : "Cuenta de la base de datos"
+    "Database account" : "Cuenta de la base de datos",
+    "Installing …" : "Instalando…"
 },
 "nplurals=2; plural=(n != 1);");
