@@ -18,15 +18,12 @@ OC.L10N.register(
     "Unknown filetype" : "Neznámý typ souboru",
     "An error occurred. Please contact your admin." : "Došlo k chybě. Obraťte se na svého správce.",
     "Invalid image" : "Neplatný obrázek",
-    "No temporary profile picture available, try again" : "Není k dispozici žádný dočasný profilový obrázek – zkuste to znovu",
-    "No crop data provided" : "Nezadáno, jak má být obrázek oříznut",
-    "No valid crop data provided" : "Neposkytnuta platná data pro oříznutí obrázku",
-    "Crop is not square" : "Ořez není čtvercový",
     "State token does not match" : "Stavový token se neshoduje",
     "Invalid app password" : "Neplatné heslo pro aplikaci",
     "Could not complete login" : "Přihlášení se nedaří dokončit",
     "State token missing" : "Chybí stavový token",
     "Your login token is invalid or has expired" : "Váš přihlašovací token není platný nebo jeho platnost skončila",
+    "Please use original client" : "Prosím použijte původního klienta",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Toto komunitní vydání Nextcloud není podporováno a push oznámení jsou proto omezená.",
     "Login" : "Přihlásit",
     "Unsupported email length (>255)" : "Nepodporovaná délka e-mailu (>255)",
@@ -34,7 +31,7 @@ OC.L10N.register(
     "Could not reset password because the token is expired" : "Heslo není možné resetovat, protože platnost tokenu skončila",
     "Could not reset password because the token is invalid" : "Heslo není možné resetovat, protože token není platný",
     "Password is too long. Maximum allowed length is 469 characters." : "Heslo je příliš dlouhé. Délka může být nejvýše 469 znaků.",
-    "%s password reset" : "reset hesla %s",
+    "%s password reset" : "Reset hesla uživatele %s",
     "Password reset" : "Reset hesla",
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Pokud chcete resetovat své heslo, klikněte na tlačítko níže. Pokud jste o resetování hesla nežádali, tento e-mail ignorujte.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Pokud chcete resetovat své heslo, klikněte na následující odkaz. Pokud jste o reset nežádali, tento e-mail ignorujte.",
@@ -43,6 +40,7 @@ OC.L10N.register(
     "Task not found" : "Úkol nenalezen",
     "Internal error" : "Vnitřní chyba",
     "Not found" : "Nenalezeno",
+    "Node is locked" : "Uzel je uzamčen",
     "Bad request" : "Chybný požadavek",
     "Requested task type does not exist" : "Požadovaný typ úkolu neexistuje",
     "Necessary language model provider is not available" : "Nezbytný poskytovatel jazykového modelu není k dsipozici",
@@ -51,6 +49,12 @@ OC.L10N.register(
     "No translation provider available" : "Není k dispozici žádný poskytovatel překladu",
     "Could not detect language" : "Nepodařilo se zjistit jazyk",
     "Unable to translate" : "Nedaří se přeložit",
+    "No valid filters provided" : "Neposkytnuty žádné platné filtry",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Krok opravy:",
+    "Repair info:" : "Informace o opravě:",
+    "Repair warning:" : "Varování ohledně opravy:",
+    "Repair error:" : "Chyba opravy:",
     "Nextcloud Server" : "Server Nextcloud",
     "Some of your link shares have been removed" : "Některá vaše sdílení odkazem byla odstraněna",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Kvůli chybě v zabezpečení bylo třeba odstranit některé z sdílení odkazem. Další informace viz odkaz.",
@@ -58,11 +62,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Aby bylo možné zvýšit limit počtu uživatelských účtů, zadejte v aplikaci podpora svůj klíč k předplatnému. Toto také zpřístupní veškeré další výhody, které nabízí Nextcloud pro podniky a je velmi doporučeno pro provozování ve firmách.",
     "Learn more ↗" : "Zjistit víc ↗",
     "Preparing update" : "Příprava pro aktualizaci",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "Krok opravy:",
-    "Repair info:" : "Informace o opravě:",
-    "Repair warning:" : "Varování ohledně opravy:",
-    "Repair error:" : "Chyba opravy:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Zaktualizujte z příkazového řádku, protože aktualizování z webového prohlížeče je vypnuté ve vašem config.php.",
     "Turned on maintenance mode" : "Přepnuto do režimu údržby",
     "Turned off maintenance mode" : "Přepnuto zpět z režimu údržby",
@@ -79,16 +78,125 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (nekompatibilní)",
     "The following apps have been disabled: %s" : "Následující aplikace byly vypnuty: %s",
     "Already up to date" : "Už je aktuální",
-    "Error occurred while checking server setup" : "Při ověřování nastavení serveru došlo k chybě",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Podrobnosti naleznete v {linkstart}dokumentaci ↗{linkend}.",
-    "unknown text" : "neznámý text",
-    "Hello world!" : "Dobrý den světe!",
-    "sunny" : "slunečno",
-    "Hello {name}, the weather is {weather}" : "Dobrý den {name}, počasí je {weather}",
-    "Hello {name}" : "Dobrý den {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Toto výsledky pro vaše hledání<script>alert(1)</script></strong>",
-    "new" : "nový",
-    "_download %n file_::_download %n files_" : ["stáhnout %n soubor","stáhnout %n soubory","stáhnout %n souborů","stáhnout %n souborů"],
+    "Windows Command Script" : "Windows cmd skript",
+    "Electronic book document" : "Dokument – elektronická knížka",
+    "TrueType Font Collection" : "Sada TrueType písem",
+    "Web Open Font Format" : "Písmo ve formátu Web Open",
+    "GPX geographic data" : "Geografická data GPX",
+    "Gzip archive" : "Gzip archiv",
+    "Adobe Illustrator document" : "Dokument Adobe Illustrator",
+    "Java source code" : "Zdrojový kód v Javě",
+    "JavaScript source code" : "Zdrojový kód v JavaScriptu",
+    "JSON document" : "JSON dokument",
+    "Microsoft Access database" : "Databáze Microsoft Access",
+    "Microsoft OneNote document" : "Dokument Microsoft OneNote",
+    "Microsoft Word document" : "Dokument Microsoft Word",
+    "Unknown" : "Neznámé",
+    "PDF document" : "PDF dokument",
+    "PostScript document" : "PostScript dokument",
+    "RSS summary" : "RSS shrnutí",
+    "Android package" : "Balíček pro Android",
+    "KML geographic data" : "Geografická data KML",
+    "KML geographic compressed data" : "Komprimovaná KLM geografická data",
+    "Lotus Word Pro document" : "Dokument Lotus Word Pro",
+    "Excel spreadsheet" : "Sešit Excel",
+    "Excel add-in" : "Doplněk do Excel",
+    "Excel 2007 binary spreadsheet" : "Sešit Excel 2007 (v binárním formátu)",
+    "Excel spreadsheet template" : "Šablona sešitu Excel",
+    "Outlook Message" : "Outlook zpráva",
+    "PowerPoint presentation" : "PowerPoint prezentace",
+    "PowerPoint add-in" : "Doplněk do PowerPoint",
+    "PowerPoint presentation template" : "Šablona prezentace PowerPoint",
+    "Word document" : "Dokument Word",
+    "ODF formula" : "ODF vzorec",
+    "ODG drawing" : "ODG kresba",
+    "ODG drawing (Flat XML)" : "Kresba ve formátu ODG (ploché XML)",
+    "ODG template" : "ODG šablona",
+    "ODP presentation" : "ODP prezentace",
+    "ODP presentation (Flat XML)" : "Prezentace ve formátu ODP (ploché XML)",
+    "ODP template" : "ODP šablona",
+    "ODS spreadsheet" : "ODS šablona",
+    "ODS spreadsheet (Flat XML)" : "Sešit ve formátu ODS (ploché XML)",
+    "ODS template" : "ODS šablona",
+    "ODT document" : "ODT dokument",
+    "ODT document (Flat XML)" : "Dokument ve formátu ODT (ploché XML)",
+    "ODT template" : "ODT šablona",
+    "PowerPoint 2007 presentation" : "Prezentace PowerPoint 2007",
+    "PowerPoint 2007 show" : "Show PowerPoint 2007",
+    "PowerPoint 2007 presentation template" : "Šablona prezentace PowerPoint 2007",
+    "Excel 2007 spreadsheet" : "Sešit Excel 2007",
+    "Excel 2007 spreadsheet template" : "Šablona sešitu Excel 2007",
+    "Word 2007 document" : "Dokument Word 2007",
+    "Word 2007 document template" : "Šablona dokumentu Word 2007",
+    "Microsoft Visio document" : "Dokument Microsoft Visio",
+    "WordPerfect document" : "WordPerfect dolument",
+    "7-zip archive" : "7-zip archiv",
+    "Blender scene" : "Scéna v Blenderu",
+    "Bzip2 archive" : "Bzip2 archiv",
+    "Debian package" : "Debian balíček",
+    "FictionBook document" : "FictionBook dokument",
+    "Unknown font" : "Neznámé písmo",
+    "Krita document" : "Krita dokument",
+    "Mobipocket e-book" : "Mobipocket e-kniha",
+    "Windows Installer package" : "Balíček Windows instalátoru",
+    "Perl script" : "Perl skript",
+    "PHP script" : "PHP skript",
+    "Tar archive" : "Tar archiv",
+    "XML document" : "XML dokument",
+    "YAML document" : "YAML dokument",
+    "Zip archive" : "Zip archiv",
+    "Zstandard archive" : "Zstandard archiv",
+    "AAC audio" : "AAC audio",
+    "FLAC audio" : "FLAC audio",
+    "MPEG-4 audio" : "MPEG-4 audio",
+    "MP3 audio" : "MP3 audio",
+    "Ogg audio" : "Ogg audio",
+    "RIFF/WAVe standard Audio" : "Audio ve standardu RIFF/WAVe",
+    "WebM audio" : "WebM audio",
+    "MP3 ShoutCast playlist" : "Seznam stop MP3 ShoutCast",
+    "Windows BMP image" : "Windows BMP obrázek",
+    "Better Portable Graphics image" : "Obrázek ve formátu Beter Portable Graphics",
+    "EMF image" : "EMF obrázek",
+    "GIF image" : "GIF obrázek",
+    "HEIC image" : "HEIC obrázek",
+    "HEIF image" : "HEIF obrázek",
+    "JPEG-2000 JP2 image" : "Obrázek JPEG-2000 JP2",
+    "JPEG image" : "JPEG obrázek",
+    "PNG image" : "Obrázek PNG",
+    "SVG image" : "SVG obrázek",
+    "Truevision Targa image" : "Obrázek Truevision Targa",
+    "TIFF image" : "TIFF obrázek",
+    "WebP image" : "WebP obrázek",
+    "Digital raw image" : "Obrázek – digitální negativ",
+    "Windows Icon" : "Windows ikona",
+    "Email message" : "E-mailová zpráva",
+    "VCS/ICS calendar" : "VCS/ICS kalednář",
+    "CSS stylesheet" : "CSS kaskádové styly",
+    "CSV document" : "CSV dokument",
+    "HTML document" : "HTML dokument",
+    "Markdown document" : "Markdown dokument",
+    "Org-mode file" : "soubor Org-mode",
+    "Plain text document" : "Dokument neformátovaného textu",
+    "Rich Text document" : "Dokument typu Rich Text",
+    "Electronic business card" : "Elektronická vizitka",
+    "C++ source code" : "Zdrojový kód v C++",
+    "LDIF address book" : "LDIF adresář kontaktů",
+    "NFO document" : "NFO dokument",
+    "PHP source" : "PHP zdrojové kódy",
+    "Python script" : "Python skript",
+    "ReStructuredText document" : "ReStructuredText dokument",
+    "3GPP multimedia file" : "3GPP soubor multimédií",
+    "MPEG video" : "MPEG video",
+    "DV video" : "DV video",
+    "MPEG-2 transport stream" : "MPEG-2 transportní proud",
+    "MPEG-4 video" : "MPEG-4 video",
+    "Ogg video" : "Ogg video",
+    "QuickTime video" : "QuickTime video",
+    "WebM video" : "WebM video",
+    "Flash video" : "Flash video",
+    "Matroska video" : "Matroska video",
+    "Windows Media video" : "Windows Media video",
+    "AVI video" : "AVI video",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Probíhá aktualizace – opuštění této stránky může v některých prostředích proces přerušit.",
     "Update to {version}" : "Aktualizovat na {version}",
     "An error occurred." : "Došlo k chybě.",
@@ -109,7 +217,7 @@ OC.L10N.register(
     "Federated user" : "Federovaný uživatel",
     "user@your-nextcloud.org" : "uzivatel@vas-nextcloud.org",
     "Create share" : "Vytvořit sdílení",
-    "Direct link copied to clipboard" : "Přímý odkaz zkopírován do schránky",
+    "Direct link copied" : "Přímý odkaz zkopírován",
     "Please copy the link manually:" : "Zkopírujte odkaz ručně:",
     "Custom date range" : "Uživatelsky určené datumové rozmezí",
     "Pick start date" : "Vybrat datum začátku",
@@ -118,14 +226,16 @@ OC.L10N.register(
     "Search in current app" : "Hledat ve stávající aplikaci",
     "Clear search" : "Vyčistit hledání",
     "Search everywhere" : "Hledat všude",
-    "Searching …" : "Hledání…",
+    "Searching …" : "Hledání …",
     "Start typing to search" : "Hledejte psaním",
+    "Minimum search length is {minSearchLength} characters" : "Nejkratší možná délka vyhledávaného řetězce je {minSearchLength} znaků",
     "No matching results" : "Žádné odpovídající výsledky",
     "Today" : "Dnes",
     "Last 7 days" : "Uplynulých 7 dnů",
     "Last 30 days" : "Uplynulých 30 dnů",
     "This year" : "Tento rok",
     "Last year" : "Uplynulý rok",
+    "Between {startDate} and {endDate}" : "Mezi {startDate} a {endDate}",
     "Unified search" : "Sjednocené vyhledávání",
     "Search apps, files, tags, messages" : "Prohledat aplikace, soubory, štítky a zprávy",
     "Places" : "Místa",
@@ -133,11 +243,12 @@ OC.L10N.register(
     "Search people" : "Hledat osoby",
     "People" : "Lidé",
     "Filter in current view" : "Filtrovat ve stávajícím pohledu",
+    "Search connected services" : "Hledat připojené služby",
     "Results" : "Výsledky",
     "Load more results" : "Načíst další výsledky",
     "Search in" : "Hledat v",
     "Log in" : "Přihlásit",
-    "Logging in …" : "Přihlašování…",
+    "Logging in …" : "Přihlašování …",
     "Log in to {productName}" : "Přihlásit se do {productName}",
     "Wrong login or password." : "Nesprávné přihlašovací jméno nebo heslo",
     "This account is disabled" : "Účet je znepřístupněn",
@@ -146,8 +257,8 @@ OC.L10N.register(
     "Account name" : "Název účtu",
     "Server side authentication failed!" : "Ověření se na straně serveru se nezdařilo!",
     "Please contact your administrator." : "Obraťte se na svého správce.",
-    "Temporary error" : "Chvilková chyba",
-    "Please try again." : "Zkuste to znovu.",
+    "Session error" : "Chyba relace",
+    "It appears your session token has expired, please refresh the page and try again." : "Zdá se, že platnost vašeho tokenu relace skončila – načtěte stránku znovu a zkuste znovu, o co jste se pokoušeli.",
     "An internal error occurred." : "Došlo k vnitřní chybě.",
     "Please try again or contact your administrator." : "Zkuste to znovu nebo se obraťte na správce.",
     "Password" : "Heslo",
@@ -174,21 +285,16 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Dokumenty, tabulky a prezentace pro spolupráci, založené na Collabora Online.",
     "Distraction free note taking app." : "Aplikace pro psaní poznámek bez rozptylování.",
     "Recommended apps" : "Doporučené aplikace",
-    "Loading apps …" : "Načítání aplikací…",
     "Could not fetch list of apps from the App Store." : "Nedaří se získat seznam aplikací z katalogu.",
     "App download or installation failed" : "Stažení aplikace nebo její instalace se nezdařilo",
     "Cannot install this app because it is not compatible" : "Tuto aplikaci nelze nainstalovat, protože není kompatibilní",
     "Cannot install this app" : "Tuto aplikaci nelze nainstalovat",
     "Skip" : "Přeskočit",
-    "Installing apps …" : "Instalace aplikací…",
     "Install recommended apps" : "Nainstalovat doporučené aplikace",
     "Avatar of {displayName}" : "Zástupný obrázek {displayName}",
     "Settings menu" : "Nabídka nastavení",
-    "Loading your contacts …" : "Načítání vašich kontaktů…",
-    "Looking for {term} …" : "Hledání {term}…",
     "Search contacts" : "Hledat v kontaktech",
     "Reset search" : "Resetovat hledání",
-    "Search contacts …" : "Hledat v kontaktech…",
     "Could not load your contacts" : "Nedaří se načíst vaše kontakty",
     "No contacts found" : "Nenalezeny žádné kontakty",
     "Show all contacts" : "Zobrazit všechny kontakty",
@@ -200,13 +306,17 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Došlo k chybě při hledání pro {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Hledání začne jakmile začnete psát a mezi výsledky je možné se pohybovat pomocí klávesami šipka nahoru/dolů",
     "Search for {name} only" : "Hledat pouze {name}",
-    "Loading more results …" : "Načítání dalších výsledků…",
     "Forgot password?" : "Zapomněli jste heslo?",
     "Back to login form" : "Zpět na formulář pro přihlášení",
     "Back" : "Zpět",
     "Login form is disabled." : "Formulář pro přihlášení je vypnut",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Přihlašovací formulář je v Nextcloud vypnutý. Použijte jinou možnost přihlášení nebo se obraťte na svého správce.",
     "More actions" : "Další akce",
+    "User menu" : "Nabídka uživatele",
+    "Your guest name: {user}" : "Vaše jméno, coby hosta: {user}",
+    "You are currently not identified." : "V tuto chvíli nejste identifikováni.",
+    "Set public name" : "Nastavit veřejné jméno",
+    "Change public name" : "Změnit veřejné jméno",
     "Password is too weak" : "Heslo je příliš snadno prolomitelné",
     "Password is weak" : "Heslo je snadno prolomitelné",
     "Password is average" : "Heslo je postačující",
@@ -239,7 +349,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Zadejte port spolu s názvem hostitele (t. j., localhost:5432).",
     "Database host" : "Stroj na kterém se nachází databáze",
     "localhost" : "localhost",
-    "Installing …" : "Instalace…",
+    "Installing …" : "Instalace …",
     "Install" : "Nainstalovat",
     "Need help?" : "Potřebujete nápovědu?",
     "See the documentation" : "Viz dokumentace",
@@ -248,7 +358,6 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Vámi využívaný webový prohlížeč není podporován. Přejděte na novější verzi nebo na nějaký podporovaný.",
     "Continue with this unsupported browser" : "Pokračovat s tímto zastaralým prohlížečem",
     "Supported versions" : "Podporované verze",
-    "Search {types} …" : "Hledat {types}…",
     "Choose {file}" : "Zvolit {file}",
     "Choose" : "Vybrat",
     "Copy to {target}" : "Zkopírovat do {target}",
@@ -268,7 +377,7 @@ OC.L10N.register(
     "(all selected)" : "(vše vybrané)",
     "({count} selected)" : "(vybráno {count})",
     "Error loading file exists template" : "Chyba při načítání šablony existence souboru",
-    "Saving …" : "Ukládání…",
+    "Saving …" : "Ukládání…",
     "seconds ago" : "před několika sekundami",
     "Connection to server lost" : "Připojení k serveru ztraceno",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problém s načítáním stránky, obnovení za %n sekundu","Problém s načítáním stránky, obnovení za %n sekundy","Problém s načítáním stránky, obnovení za %n sekund","Problém s načítáním stránky, obnovení za %n sekund"],
@@ -283,26 +392,18 @@ OC.L10N.register(
     "Type to search for existing projects" : "Psaním vyhledávejte existující projekty",
     "New in" : "Nové v",
     "View changelog" : "Zobrazit souhrn změn",
-    "No action available" : "Není dostupná žádná akce",
-    "Error fetching contact actions" : "Chyba při získávání akcí kontaktů",
     "Close \"{dialogTitle}\" dialog" : "Zavřít „{dialogTitle}“ dialog",
     "Email length is at max (255)" : "Délka e-mailu je na maximu (255)",
-    "Non-existing tag #{tag}" : "Neexistující štítek #{tag}",
-    "Restricted" : "Omezeno",
-    "Invisible" : "Není vidět",
-    "Delete" : "Smazat",
-    "Rename" : "Přejmenovat",
-    "Collaborative tags" : "Štítky pro spolupráci",
-    "No tags found" : "Nenalezeny žádné štítky",
     "Clipboard not available, please copy manually" : "Schránka není k dispozici – zkopírujte ručně",
     "Personal" : "Osobní",
     "Accounts" : "Účty",
     "Admin" : "Správa",
     "Help" : "Nápověda",
     "Access forbidden" : "Přístup zakázán",
+    "You are not allowed to access this page." : "Nemáte oprávnění k přístupu k této stránce.",
+    "Back to %s" : "Zpět na %s",
     "Page not found" : "Stránka nenalezena",
     "The page could not be found on the server or you may not be allowed to view it." : "Stránku se na serveru nepodařilo nalézt nebo nemáte oprávnění ji zobrazit.",
-    "Back to %s" : "Zpět na %s",
     "Too many requests" : "Příliš mnoho požadavků",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Z vaší sítě bylo příliš mnoho požadavků. Zkuste to později nebo (pokud je toto chyba) se obraťte na svého správce.",
     "Error" : "Chyba",
@@ -378,23 +479,41 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Tato instance %s se právě nachází v režimu údržby a ta může chvíli trvat.",
     "This page will refresh itself when the instance is available again." : "Tato stránka se automaticky znovu načte, jakmile bude tato instance opět dostupná.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Pokud se tato zpráva objevuje trvale nebo nečekaně, obraťte se na správce systému.",
-    "Currently open" : "Nyní otevřeno",
-    "Login with username or email" : "Přihlásit se uživatelským jménem nebo e-mailem",
-    "Login with username" : "Přihlásit se uživatelským jménem",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatování, videohovory, sdílení obrazovky, schůze na dálku a webové konference – ve webovém prohlížeči a mobilních aplikacích.",
-    "You have not added any info yet" : "Zatím jste nezadali žádné informace",
-    "{user} has not added any info yet" : "{user} uživatel zatím nezadal žádné informace",
-    "Error opening the user status modal, try hard refreshing the page" : "Chyba při otevírání dialogu stavu uživatele, pokus o opětovné načtení stránky",
-    "Edit Profile" : "Upravit profil",
-    "The headline and about sections will show up here" : "Nadpis a sekce o uživatelích se zobrazí zde",
-    "Error loading message template: {error}" : "Chyba při načítání šablony zprávy: {error}",
+    "Error occurred while checking server setup" : "Při ověřování nastavení serveru došlo k chybě",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Podrobnosti naleznete v {linkstart}dokumentaci ↗{linkend}.",
+    "unknown text" : "neznámý text",
+    "Hello world!" : "Dobrý den světe!",
+    "sunny" : "slunečno",
+    "Hello {name}, the weather is {weather}" : "Dobrý den {name}, počasí je {weather}",
+    "Hello {name}" : "Dobrý den {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Toto výsledky pro vaše hledání<script>alert(1)</script></strong>",
+    "new" : "nový",
+    "_download %n file_::_download %n files_" : ["stáhnout %n soubor","stáhnout %n soubory","stáhnout %n souborů","stáhnout %n souborů"],
+    "Direct link copied to clipboard" : "Přímý odkaz zkopírován do schránky",
+    "Searching …" : "Hledání…",
+    "Logging in …" : "Přihlašování…",
+    "Loading apps …" : "Načítání aplikací…",
+    "Installing apps …" : "Instalace aplikací…",
+    "Loading your contacts …" : "Načítání vašich kontaktů…",
+    "Looking for {term} …" : "Hledání {term}…",
+    "Search contacts …" : "Hledat v kontaktech…",
+    "Loading more results …" : "Načítání dalších výsledků…",
+    "Search {types} …" : "Hledat {types}…",
+    "Saving …" : "Ukládání…",
     "Very weak password" : "Velmi snadno prolomitelné heslo",
     "Weak password" : "Snadno prolomitelné heslo",
     "So-so password" : "Ještě použitelné heslo",
     "Good password" : "Dobré heslo",
     "Strong password" : "Odolné heslo",
-    "Profile not found" : "Profil nenalezen",
-    "The profile does not exist." : "Profil neexistuje.",
+    "No action available" : "Není dostupná žádná akce",
+    "Error fetching contact actions" : "Chyba při získávání akcí kontaktů",
+    "Non-existing tag #{tag}" : "Neexistující štítek #{tag}",
+    "Restricted" : "Omezeno",
+    "Invisible" : "Není vidět",
+    "Delete" : "Smazat",
+    "Rename" : "Přejmenovat",
+    "Collaborative tags" : "Štítky pro spolupráci",
+    "No tags found" : "Nenalezeny žádné štítky",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Váš adresář data a soubory jsou přístupné z Internetu, protože soubor .htaccess nefunguje.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informace o tom, jak správně nastavit svůj server, naleznete v <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaci</a>.",
     "<strong>Create an admin account</strong>" : "</strong>Vytvořit účet správce</strong>",
@@ -404,6 +523,7 @@ OC.L10N.register(
     "Toggle password visibility" : "Přepnout viditelnost hesla",
     "Configure the database" : "Nastavit databázi",
     "Only %s is available." : "Je k dispozici pouze %s.",
-    "Database account" : "Účet do databáze"
+    "Database account" : "Účet do databáze",
+    "Installing …" : "Instalace…"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
