@@ -18,15 +18,12 @@ OC.L10N.register(
     "Unknown filetype" : "Tipo di file sconosciuto",
     "An error occurred. Please contact your admin." : "Si è verificato un errore. Contatta il tuo amministratore.",
     "Invalid image" : "Immagine non valida",
-    "No temporary profile picture available, try again" : "Nessuna immagine di profilo provvisoria disponibile, riprova",
-    "No crop data provided" : "Non sono stati forniti dati di ritaglio",
-    "No valid crop data provided" : "Non sono stati forniti dati di ritaglio validi",
-    "Crop is not square" : "Il ritaglio non è quadrato",
     "State token does not match" : "Il token di stato non corrisponde",
     "Invalid app password" : "Password dell'applicazione non valida",
     "Could not complete login" : "Impossibile completare l'accesso",
     "State token missing" : "Token di stato mancante",
     "Your login token is invalid or has expired" : "Il tuo token di accesso non è valido o è scaduto",
+    "Please use original client" : "Si prega di utilizzare il client originale",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Questa versione della comunità di Nextcloud non è supportata e le notifiche push sono limitate.",
     "Login" : "Accedi",
     "Unsupported email length (>255)" : "Lunghezza email non supportata (>255)",
@@ -43,6 +40,7 @@ OC.L10N.register(
     "Task not found" : "Attività non trovata",
     "Internal error" : "Errore interno",
     "Not found" : "Non trovato",
+    "Node is locked" : "Il nodo è bloccato",
     "Bad request" : "Richiesta errata",
     "Requested task type does not exist" : "Il tipo di attività richiesto non esiste",
     "Necessary language model provider is not available" : "Il necessario provider di modello per la lingua non è disponibile",
@@ -51,6 +49,12 @@ OC.L10N.register(
     "No translation provider available" : "Nessun fornitore di traduzioni disponibile",
     "Could not detect language" : "Impossibile rilevare la lingua",
     "Unable to translate" : "Impossibile tradurre",
+    "No valid filters provided" : "Nessun filtro valido fornito",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Fase di riparazione:",
+    "Repair info:" : "Informazioni di riparazione:",
+    "Repair warning:" : "Avviso di riparazione",
+    "Repair error:" : "Errore di riparazione:",
     "Nextcloud Server" : "Server Nextcloud",
     "Some of your link shares have been removed" : "Alcune delle tue condivisioni tramite collegamento sono state rimosse",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "A causa di un bug di sicurezza abbiamo rimosso alcune delle tue condivisioni tramite collegamento. Vedi il collegamento per ulteriori informazioni.",
@@ -58,11 +62,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Inserisci la tua chiave di abbonamento nell'applicazione di supporto per aumentare il limite di utenti. In questo modo otterrai anche tutti i vantaggi aggiuntivi che Nextcloud Enterprise offre ed è altamente consigliato per l'operatività nelle aziende.",
     "Learn more ↗" : "Ulteriori informazioni ↗",
     "Preparing update" : "Preparazione dell'aggiornamento",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "Fase di riparazione:",
-    "Repair info:" : "Informazioni di riparazione:",
-    "Repair warning:" : "Avviso di riparazione",
-    "Repair error:" : "Errore di riparazione:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Utilizza lo strumento da riga di comando poiché l'aggiornamento da browser è disabilitato nel file config.php.",
     "Turned on maintenance mode" : "Modalità di manutenzione attivata",
     "Turned off maintenance mode" : "Modalità di manutenzione disattivata",
@@ -79,16 +78,125 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (incompatibile)",
     "The following apps have been disabled: %s" : "Le seguenti applicazioni sono state disabilitate: %s",
     "Already up to date" : "Già aggiornato",
-    "Error occurred while checking server setup" : "Si è verificato un errore durante il controllo della configurazione del server",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Per ulteriori dettagli, leggi la {linkstart}documentazione ↗{linkend}.",
-    "unknown text" : "testo sconosciuto",
-    "Hello world!" : "Ciao mondo!",
-    "sunny" : "soleggiato",
-    "Hello {name}, the weather is {weather}" : "Ciao {name}, il tempo è {weather}",
-    "Hello {name}" : "Ciao {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Questi sono i tuoi risultati di ricerca<script>alert(1)</script></strong>",
-    "new" : "nuovo",
-    "_download %n file_::_download %n files_" : ["scarica %n file","scarica %n file","scarica %n file"],
+    "Windows Command Script" : "Script dei comandi di Windows",
+    "Electronic book document" : "Documento libro elettronico",
+    "TrueType Font Collection" : "Raccolta di font TrueType",
+    "Web Open Font Format" : "Formato Web Open Font",
+    "GPX geographic data" : "Dati geografici GPX",
+    "Gzip archive" : "Archivio Gzip",
+    "Adobe Illustrator document" : "Documento di Adobe Illustrator",
+    "Java source code" : "Codice sorgente Java",
+    "JavaScript source code" : "Codice sorgente JavaScript",
+    "JSON document" : "Documento JSON",
+    "Microsoft Access database" : "Database di Microsoft Access",
+    "Microsoft OneNote document" : "Documento di Microsoft OneNote",
+    "Microsoft Word document" : "Documento di Microsoft Word",
+    "Unknown" : "Sconosciuto",
+    "PDF document" : "Documento PDF",
+    "PostScript document" : "Documento PostScript",
+    "RSS summary" : "Riepilogo RSS",
+    "Android package" : "Pacchetto Android",
+    "KML geographic data" : "Dati geografici KML",
+    "KML geographic compressed data" : "Dati geografici compressi KML",
+    "Lotus Word Pro document" : "Documento Lotus Word Pro",
+    "Excel spreadsheet" : "Foglio di calcolo Excel",
+    "Excel add-in" : "Componente aggiuntivo di Excel",
+    "Excel 2007 binary spreadsheet" : "Foglio di calcolo binario di Excel 2007",
+    "Excel spreadsheet template" : "Modello di foglio di calcolo Excel",
+    "Outlook Message" : "Messaggio di Outlook",
+    "PowerPoint presentation" : "Presentazione PowerPoint",
+    "PowerPoint add-in" : "Componente aggiuntivo di PowerPoint",
+    "PowerPoint presentation template" : "Modello di presentazione di PowerPoint",
+    "Word document" : "Documento Word",
+    "ODF formula" : "Formula ODF",
+    "ODG drawing" : "Disegno ODG",
+    "ODG drawing (Flat XML)" : "Disegno ODG (XML piatto)",
+    "ODG template" : "Modello ODG",
+    "ODP presentation" : "Presentazione ODP",
+    "ODP presentation (Flat XML)" : "Presentazione ODP (XML piatto)",
+    "ODP template" : "Modello ODP",
+    "ODS spreadsheet" : "Foglio di calcolo ODS",
+    "ODS spreadsheet (Flat XML)" : "Foglio di calcolo ODS (XML piatto)",
+    "ODS template" : "Modello ODS",
+    "ODT document" : "Documento ODT",
+    "ODT document (Flat XML)" : "Documento ODT (XML piatto)",
+    "ODT template" : "Modello ODT",
+    "PowerPoint 2007 presentation" : "Presentazione PowerPoint 2007",
+    "PowerPoint 2007 show" : "Visualizzatore di PowerPoint 2007",
+    "PowerPoint 2007 presentation template" : "Modello di presentazione di PowerPoint 2007",
+    "Excel 2007 spreadsheet" : "Foglio di calcolo Excel 2007",
+    "Excel 2007 spreadsheet template" : "Modello di foglio di calcolo di Excel 2007",
+    "Word 2007 document" : "Documento di Word 2007",
+    "Word 2007 document template" : "Modello di documento Word 2007",
+    "Microsoft Visio document" : "Documento di Microsoft Visio",
+    "WordPerfect document" : "Documento WordPerfect",
+    "7-zip archive" : "Archivio 7-zip",
+    "Blender scene" : "Scena di Blender",
+    "Bzip2 archive" : "Archivio Bzip2",
+    "Debian package" : "Pacchetto Debian",
+    "FictionBook document" : "Documento FictionBook",
+    "Unknown font" : "Font sconosciuto",
+    "Krita document" : "Documento Krita",
+    "Mobipocket e-book" : "E-book Mobipocket",
+    "Windows Installer package" : "Pacchetto di installazione di Windows",
+    "Perl script" : "Script Perl",
+    "PHP script" : "Script PHP",
+    "Tar archive" : "Archivio Tar",
+    "XML document" : "Documento XML",
+    "YAML document" : "Documento YAML",
+    "Zip archive" : "Archivio zip",
+    "Zstandard archive" : "Archivio Zstandard",
+    "AAC audio" : "Audio AAC",
+    "FLAC audio" : "Audio FLAC",
+    "MPEG-4 audio" : "Audio MPEG-4",
+    "MP3 audio" : "Audio MP3",
+    "Ogg audio" : "Audio Ogg",
+    "RIFF/WAVe standard Audio" : "Standard audio RIFF/WAVe",
+    "WebM audio" : "Audio WebM",
+    "MP3 ShoutCast playlist" : "Playlist MP3 ShoutCast",
+    "Windows BMP image" : "Immagine BMP di Windows",
+    "Better Portable Graphics image" : "Migliore immagine grafica portatile",
+    "EMF image" : "Immagine EMF",
+    "GIF image" : "Immagine GIF",
+    "HEIC image" : "Immagine HEIC",
+    "HEIF image" : "Immagine HEIF",
+    "JPEG-2000 JP2 image" : "Immagine JPEG-2000 JP2",
+    "JPEG image" : "Immagine JPEG",
+    "PNG image" : "Immagine PNG",
+    "SVG image" : "Immagine SVG",
+    "Truevision Targa image" : "Immagine Truevision Targa",
+    "TIFF image" : "Immagine TIFF",
+    "WebP image" : "Immagine WebP",
+    "Digital raw image" : "Immagine digitale raw",
+    "Windows Icon" : "Icona di Windows",
+    "Email message" : "messaggio di posta elettronica",
+    "VCS/ICS calendar" : "Calendario VCS/ICS",
+    "CSS stylesheet" : "Foglio di stile CSS",
+    "CSV document" : "Documento CSV",
+    "HTML document" : "Documento HTML",
+    "Markdown document" : "Documento Markdown",
+    "Org-mode file" : "File Org-mode",
+    "Plain text document" : "Documento di testo normale",
+    "Rich Text document" : "Documento Rich Text",
+    "Electronic business card" : "Biglietto da visita elettronico",
+    "C++ source code" : "Codice sorgente C++",
+    "LDIF address book" : "Rubrica LDIF",
+    "NFO document" : "Documento NFO",
+    "PHP source" : "Sorgente PHP",
+    "Python script" : "Script Python",
+    "ReStructuredText document" : "Documento ReStructuredText",
+    "3GPP multimedia file" : "File multimediale 3GPP",
+    "MPEG video" : "Video MPEG",
+    "DV video" : "Video DV",
+    "MPEG-2 transport stream" : "Flusso di trasporto MPEG-2",
+    "MPEG-4 video" : "Video MPEG-4",
+    "Ogg video" : "Video Ogg",
+    "QuickTime video" : "Video QuickTime",
+    "WebM video" : "Video WebM",
+    "Flash video" : "Video flash",
+    "Matroska video" : "Video Matroska",
+    "Windows Media video" : "Video di Windows Media",
+    "AVI video" : "Video AVI",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "L'aggiornamento è in corso, l'abbandono di questa pagina potrebbe interrompere il processo in alcuni ambienti.",
     "Update to {version}" : "Aggiorna a {version}",
     "An error occurred." : "Si è verificato un errore.",
@@ -109,7 +217,7 @@ OC.L10N.register(
     "Federated user" : "Utente federato",
     "user@your-nextcloud.org" : "utente@il-tuo-nextcloud.org",
     "Create share" : "Crea condivisione",
-    "Direct link copied to clipboard" : "Collegamento diretto copiato negli appunti",
+    "Direct link copied" : "Link diretto copiato",
     "Please copy the link manually:" : "Copia il collegamento manualmente:",
     "Custom date range" : "Intervallo di date personalizzato",
     "Pick start date" : "Scegli la data di inizio",
@@ -118,14 +226,16 @@ OC.L10N.register(
     "Search in current app" : "Cerca nell'applicazione attuale",
     "Clear search" : "Svuota ricerca",
     "Search everywhere" : "Cerca ovunque",
-    "Searching …" : "Ricerca in corso…",
+    "Searching …" : "Ricerca in corso …",
     "Start typing to search" : "Inizia a digitare per cercare",
+    "Minimum search length is {minSearchLength} characters" : "La lunghezza minima della ricerca è {minSearchLength} caratteri",
     "No matching results" : "Nessun risultato corrispondente",
     "Today" : "Ogg",
     "Last 7 days" : "Ultimi 7 giorni",
     "Last 30 days" : "Ultimi 30 giorni",
     "This year" : "Quest'anno",
     "Last year" : "Ultimo anno",
+    "Between {startDate} and {endDate}" : "Tra {startDate} e {endDate}",
     "Unified search" : "Ricerca unificata",
     "Search apps, files, tags, messages" : "Cerca applicazioni. file, etichette, messaggi",
     "Places" : "Luoghi",
@@ -133,11 +243,12 @@ OC.L10N.register(
     "Search people" : "Cerca le persone",
     "People" : "Persone",
     "Filter in current view" : "Filtro nella vista corrente",
+    "Search connected services" : "Cerca servizi connessi",
     "Results" : "Risultati",
     "Load more results" : "Carica più risultati",
     "Search in" : "Cerca all'interno",
     "Log in" : "Accedi",
-    "Logging in …" : "Accesso in corso...",
+    "Logging in …" : "Accesso in corso ...",
     "Log in to {productName}" : "Accedi a {productName}",
     "Wrong login or password." : "Nome utente o password errati.",
     "This account is disabled" : "Questo account è disabilitato",
@@ -146,6 +257,8 @@ OC.L10N.register(
     "Account name" : "Nome account",
     "Server side authentication failed!" : "Autenticazione lato server non riuscita!",
     "Please contact your administrator." : "Contatta il tuo amministratore di sistema.",
+    "Session error" : "Errore di sessione",
+    "It appears your session token has expired, please refresh the page and try again." : "Sembra che il token di sessione sia scaduto. Aggiorna la pagina e riprova.",
     "An internal error occurred." : "Si è verificato un errore interno.",
     "Please try again or contact your administrator." : "Prova ancora o contatta il tuo amministratore.",
     "Password" : "Password",
@@ -172,21 +285,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documenti collaborativi, fogli di calcolo e presentazioni, integrati in Collabora Online.",
     "Distraction free note taking app." : "Applicazione per note, senza distrazioni.",
     "Recommended apps" : "Applicazioni consigliate",
-    "Loading apps …" : "Caricamento applicazioni…",
+    "Loading apps …" : "Caricamento app …",
     "Could not fetch list of apps from the App Store." : "Impossibile scaricare l'elenco delle applicazioni dal negozio delle applicazioni.",
     "App download or installation failed" : "Scaricamento o installazione dell'applicazione non riuscito",
     "Cannot install this app because it is not compatible" : "Impossibile installare questa applicazione poiché non è compatibile",
     "Cannot install this app" : "Impossibile installare questa applicazione",
     "Skip" : "Salta",
-    "Installing apps …" : "Installazione applicazioni…",
+    "Installing apps …" : "Installazione app …",
     "Install recommended apps" : "Installa applicazioni consigliate",
     "Avatar of {displayName}" : "Avatar di {displayName}",
     "Settings menu" : "Menu delle impostazioni",
-    "Loading your contacts …" : "Caricamento dei tuoi contatti...",
-    "Looking for {term} …" : "Ricerca di {term} in corso...",
+    "Loading your contacts …" : "Caricamento dei tuoi contatti …",
+    "Looking for {term} …" : "Ricerca di {term} …",
     "Search contacts" : "Cerca nei contatti",
     "Reset search" : "Ripristina ricerca",
-    "Search contacts …" : "Cerca contatti...",
+    "Search contacts …" : "Cerca contatti …",
     "Could not load your contacts" : "Impossibile caricare i tuoi contatti",
     "No contacts found" : "Nessun contatto trovato",
     "Show all contacts" : "Mostra tutti i contatti",
@@ -198,29 +311,53 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Si è verificato un errore durante la ricerca di {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "La ricerca inizia nel momento in cui digiti e puoi vedere i risultati con i tasti freccia",
     "Search for {name} only" : "Cerca solo {name}",
-    "Loading more results …" : "Caricamento di più risultati...",
+    "Loading more results …" : "Caricamento di altri risultati …",
     "Forgot password?" : "Hai dimenticato la password?",
     "Back to login form" : "Torna al modulo di accesso",
     "Back" : "Indietro",
     "Login form is disabled." : "Il modulo di accesso è disabilitato.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Il modulo di accesso a Nextcloud è disabilitato. Usa un'altra opzione di accesso, se disponibile, o contatta l'amministratore.",
     "More actions" : "Altre azioni",
+    "User menu" : "Menu utente",
+    "Your guest name: {user}" : "Il tuo nome ospite: {user}",
+    "You are currently not identified." : "Al momento non sei stato identificato.",
+    "Set public name" : "Imposta nome pubblico",
+    "Change public name" : "Cambia nome pubblico",
+    "Password is too weak" : "La password è troppo debole",
+    "Password is weak" : "La password è debole",
+    "Password is average" : "La password è mediocre",
+    "Password is strong" : "La password è forte",
+    "Password is very strong" : "La password è molto forte",
+    "Password is extremely strong" : "La password è estremamente forte",
+    "Unknown password strength" : "Sicurezza della password sconosciuta",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Probabilmente la directory dei dati e i file sono accessibili da Internet perché il file <code>.htaccess</code> non funziona.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Per informazioni su come configurare correttamente il tuo server, {linkStart}consultare la documentazione{linkEnd}",
+    "Autoconfig file detected" : "File di configurazione automatica rilevato",
+    "The setup form below is pre-filled with the values from the config file." : "Il modulo di configurazione riportato di seguito è precompilato con i valori del file di configurazione.",
     "Security warning" : "Avviso di sicurezza",
+    "Create administration account" : "Crea un account amministrazione",
+    "Administration account name" : "Nome dell'account di amministrazione",
+    "Administration account password" : "Password dell'account di amministrazione",
     "Storage & database" : "Archiviazione e database",
     "Data folder" : "Cartella dati",
+    "Database configuration" : "Configurazione del database",
+    "Database type" : "Tipo di database",
+    "Only {firstAndOnlyDatabase} is available." : "Solo {firstAndOnlyDatabase} è disponibile.",
     "Install and activate additional PHP modules to choose other database types." : "Installa e attiva i moduli PHP aggiuntivi per scegliere gli altri tipi di database.",
     "For more details check out the documentation." : "Per ulteriori dettagli, leggi la documentazione.",
     "Performance warning" : "Avviso di prestazioni",
     "You chose SQLite as database." : "Hai scelto SQLite come database.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite dovrebbe essere scelto solo per istanze minimali e di sviluppo. Per la produzione, consigliamo un motore di database diverso.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Se utilizzi client per la sincronizzazione dei file, l'uso di SQLite è sconsigliato.",
+    "Database connection" : "Connessione al database",
     "Database user" : "Utente del database",
     "Database password" : "Password del database",
     "Database name" : "Nome del database",
     "Database tablespace" : "Spazio delle tabelle del database",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Specifica il numero della porta insieme al nome host (ad es. localhost:5432).",
     "Database host" : "Host del database",
-    "Installing …" : "Installazione …",
+    "localhost" : "localhost",
+    "Installing …" : "Installazione …",
     "Install" : "Installa",
     "Need help?" : "Ti serve aiuto?",
     "See the documentation" : "Leggi la documentazione",
@@ -229,7 +366,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Il tuo browser non è supportato. Effettua l'aggiornamento a una versione più recente o supportata.",
     "Continue with this unsupported browser" : "Prosegui con questo browser non supportato",
     "Supported versions" : "Versioni supportate",
-    "Search {types} …" : "Cerca {types}...",
+    "Search {types} …" : "Cerca {types} …",
     "Choose {file}" : "Scegli {file}",
     "Choose" : "Scegli",
     "Copy to {target}" : "Copia in {target}",
@@ -249,7 +386,7 @@ OC.L10N.register(
     "(all selected)" : "(tutti i selezionati)",
     "({count} selected)" : "({count} selezionati)",
     "Error loading file exists template" : "Errore durante il caricamento del modello del file esistente",
-    "Saving …" : "Salvataggio…",
+    "Saving …" : "Salvataggio…",
     "seconds ago" : "secondi fa",
     "Connection to server lost" : "Connessione al server interrotta",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema durante il caricamento della pagina, aggiornamento tra %n secondo","Problema durante il caricamento della pagina, aggiornamento tra %n secondi","Problema durante il caricamento della pagina, aggiornamento tra %n secondi"],
@@ -264,26 +401,18 @@ OC.L10N.register(
     "Type to search for existing projects" : "Digita per cercare progetti esistenti",
     "New in" : "Nuovo in",
     "View changelog" : "Visualizza le novità",
-    "No action available" : "Nessuna azione disponibile",
-    "Error fetching contact actions" : "Errore durante il recupero delle azioni dei contatti",
     "Close \"{dialogTitle}\" dialog" : "Chiudi la finestra \"{dialogTitle}\"",
     "Email length is at max (255)" : "La lunghezza dell'email è al massimo (255)",
-    "Non-existing tag #{tag}" : "Etichetta #{tag} inesistente",
-    "Restricted" : "Limitato",
-    "Invisible" : "Invisibile",
-    "Delete" : "Elimina",
-    "Rename" : "Rinomina",
-    "Collaborative tags" : "Etichette collaborative",
-    "No tags found" : "Nessuna etichetta trovata",
     "Clipboard not available, please copy manually" : "Appunti non disponibili, copiare manualmente",
     "Personal" : "Personale",
     "Accounts" : "Account",
     "Admin" : "Admin",
     "Help" : "Aiuto",
     "Access forbidden" : "Accesso negato",
+    "You are not allowed to access this page." : "Non ti è consentito accedere a questa pagina.",
+    "Back to %s" : "Torna a %s",
     "Page not found" : "Pagina non trovata",
     "The page could not be found on the server or you may not be allowed to view it." : "La pagina non è stata trovata sul server o forse non ti è permesso vederla.",
-    "Back to %s" : "Torna a %s",
     "Too many requests" : "Troppe richieste",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Sono arrivate troppe richieste dalla tua rete. Riprova più tardi o contatta il tuo amministratore se questo è un errore.",
     "Error" : "Errore",
@@ -359,23 +488,41 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Questa istanza di %s è attualmente in manutenzione, potrebbe richiedere del tempo.",
     "This page will refresh itself when the instance is available again." : "Questa pagina si aggiornerà quando l'istanza sarà nuovamente disponibile.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contatta il tuo amministratore di sistema se questo messaggio persiste o appare inaspettatamente.",
-    "Currently open" : "Attualmente aperto",
-    "Login with username or email" : "Accedi con nome utente o email",
-    "Login with username" : "Accedi con il nome utente",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chat, videochiamate, condivisione schermo, riunioni in linea e conferenze web – nel tuo browser e con le applicazioni mobili.",
-    "You have not added any info yet" : "Non hai ancora aggiunto alcuna informazione",
-    "{user} has not added any info yet" : "{user} non ha ancora aggiunto alcuna informazione",
-    "Error opening the user status modal, try hard refreshing the page" : "Errore nell'apertura dello stato utente, prova a ricaricare la pagina",
-    "Edit Profile" : "Modifica il profilo",
-    "The headline and about sections will show up here" : "Le sezioni del titolo e delle informazioni verranno mostrate qui",
-    "Error loading message template: {error}" : "Errore durante il caricamento del modello di messaggio: {error}",
+    "Error occurred while checking server setup" : "Si è verificato un errore durante il controllo della configurazione del server",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Per ulteriori dettagli, leggi la {linkstart}documentazione ↗{linkend}.",
+    "unknown text" : "testo sconosciuto",
+    "Hello world!" : "Ciao mondo!",
+    "sunny" : "soleggiato",
+    "Hello {name}, the weather is {weather}" : "Ciao {name}, il tempo è {weather}",
+    "Hello {name}" : "Ciao {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Questi sono i tuoi risultati di ricerca<script>alert(1)</script></strong>",
+    "new" : "nuovo",
+    "_download %n file_::_download %n files_" : ["scarica %n file","scarica %n file","scarica %n file"],
+    "Direct link copied to clipboard" : "Collegamento diretto copiato negli appunti",
+    "Searching …" : "Ricerca in corso…",
+    "Logging in …" : "Accesso in corso...",
+    "Loading apps …" : "Caricamento applicazioni…",
+    "Installing apps …" : "Installazione applicazioni…",
+    "Loading your contacts …" : "Caricamento dei tuoi contatti...",
+    "Looking for {term} …" : "Ricerca di {term} in corso...",
+    "Search contacts …" : "Cerca contatti...",
+    "Loading more results …" : "Caricamento di più risultati...",
+    "Search {types} …" : "Cerca {types}...",
+    "Saving …" : "Salvataggio…",
     "Very weak password" : "Password molto debole",
     "Weak password" : "Password debole",
     "So-so password" : "Password così-così",
     "Good password" : "Password buona",
     "Strong password" : "Password forte",
-    "Profile not found" : "Profilo non trovato",
-    "The profile does not exist." : "Il profilo non esiste.",
+    "No action available" : "Nessuna azione disponibile",
+    "Error fetching contact actions" : "Errore durante il recupero delle azioni dei contatti",
+    "Non-existing tag #{tag}" : "Etichetta #{tag} inesistente",
+    "Restricted" : "Limitato",
+    "Invisible" : "Invisibile",
+    "Delete" : "Elimina",
+    "Rename" : "Rinomina",
+    "Collaborative tags" : "Etichette collaborative",
+    "No tags found" : "Nessuna etichetta trovata",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "La cartella dei dati e i file sono probabilmente accessibili da Internet poiché il file .htaccess non funziona.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Per informazioni su come configurare correttamente il tuo server, vedi la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentazione</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Crea un account amministratore</strong>",
@@ -385,6 +532,7 @@ OC.L10N.register(
     "Toggle password visibility" : "Commuta la visibilità delle password",
     "Configure the database" : "Configura il database",
     "Only %s is available." : "È disponibile solo %s.",
-    "Database account" : "Database account"
+    "Database account" : "Database account",
+    "Installing …" : "Installazione …"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
