@@ -25,6 +25,7 @@ OC.L10N.register(
     "Your login token is invalid or has expired" : "โทเค็นเข้าสู่ระบบของคุณไม่ถูกต้องหรือหมดอายุแล้ว",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "คอมมูนิตี้เวอร์ชันนี้ของ Nextcloud ไม่ได้รับการสนับสนุนและการแจ้งเตือนแบบพุชถูกจำกัด",
     "Login" : "เข้าสู่ระบบ",
+    "Unsupported email length (>255)" : "อีเมลมีความยาวมากเกินไป (เกิน 255 อักขระ)",
     "Password reset is disabled" : "การตั้งรหัสผ่านใหม่ถูกปิดใช้งาน",
     "Could not reset password because the token is expired" : "ไม่สามารถรีเซ็ตรหัสผ่านได้ เนื่องจาก Token หมดอายุ",
     "Could not reset password because the token is invalid" : "ไม่สามารถรีเซ็ตรหัสผ่านได้ เนื่องจาก Token ไม่ถูกต้อง",
@@ -34,9 +35,12 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "คลิกปุ่มด้านล่างเพื่อตั้งรหัสผ่านของคุณใหม่ หากคุณไม่ได้ขอการตั้งรหัสผ่านใหม่ สามารถเพิกเฉยอีเมลนี้",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "คลิกลิงก์ด้านล่างเพื่อตั้งรหัสผ่านของคุณใหม่ หากคุณไม่ได้ขอการตั้งรหัสผ่านใหม่ สามารถเพิกเฉยอีเมลนี้",
     "Reset your password" : "ตั้งรหัสผ่านของคุณใหม่",
+    "The given provider is not available" : "ผู้ให้บริการนี้ไม่สามารถใช้งานได้",
     "Task not found" : "ไม่พบงาน",
     "Internal error" : "ข้อผิดพลาดภายใน",
     "Not found" : "ไม่พบสิ่งที่ต้องการ",
+    "Node is locked" : "โหนดถูกล็อก",
+    "Bad request" : "คำร้องขอไม่ถูกต้อง",
     "Requested task type does not exist" : "ไม่มีประเภทงานที่ร้องขออยู่",
     "Necessary language model provider is not available" : "ผู้ให้บริการโมเดลภาษาที่จำเป็นไม่สามารถใช้ได้",
     "No text to image provider is available" : "ไม่มีผู้ให้บริการแปลงข้อความเป็นรูปภาพที่พร้อมใช้งาน",
@@ -44,6 +48,7 @@ OC.L10N.register(
     "No translation provider available" : "ไม่มีผู้ให้บริการแปลที่พร้อมใช้งาน",
     "Could not detect language" : "ไม่สามารถตรวจจับภาษา",
     "Unable to translate" : "ไม่สามารถแปล",
+    "No valid filters provided" : "ไม่พบตัวกรองที่ให้มา",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "ขั้นตอนการซ่อมแซม:",
     "Repair info:" : "ข้อมูลการซ่อมแซม:",
@@ -53,8 +58,10 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "ลิงก์แชร์บางลิงก์ของคุณถูกลบออก",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "เนื่องจากข้อบกพร่องความปลอดภัย เราจำเป็นต้องลบลิงก์แชร์บางลิงก์ของคุณออก โปรดดูที่ลิงก์สำหรับข้อมูลเพิ่มเติม",
     "The account limit of this instance is reached." : "ถึงขีดจำกัดจำนวนบัญชีของเซิร์ฟเวอร์นี้แล้ว",
+    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "กรุณาใส่รหัสที่ได้จากการสมัครบริการลงใน support app เพื่อเพิ่มความสามารถการใช้งานและผลประโยชน์อื่น ๆ ที่มีให้เฉพาะผลิตภันฑ์ Nextcloud Enterprise ซึ่งเป็นที่แนะนำอย่างยิ่งในการทำงานของหน่วยงานท่าน",
     "Learn more ↗" : "เรียนรู้เพิ่มเติม ↗",
     "Preparing update" : "กำลังเตรียมอัปเดต",
+    "Please use the command line updater because updating via browser is disabled in your config.php." : "กรุณาทำการอัพเดทโดยใช้คำสั่ง command line เนื่องจากการอัพเดทผ่านทางบราวเซอร์ถูกปิดการใช้งานจากไฟล์ config.php",
     "Turned on maintenance mode" : "เปิดโหมดการบำรุงรักษาแล้ว",
     "Turned off maintenance mode" : "ปิดโหมดการบำรุงรักษาแล้ว",
     "Maintenance mode is kept active" : "โหมดการบำรุงรักษาถูกเปิดไว้",
@@ -70,15 +77,19 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (เข้ากันไม่ได้)",
     "The following apps have been disabled: %s" : "แอปต่อไปนี้ถูกปิดการใช้งาน: %s",
     "Already up to date" : "ล่าสุดแล้ว",
+    "Windows Command Script" : "สคริปคำสั่งระบบวินโวส์",
+    "Electronic book document" : "เอกสารหนังสืออิเล็กทรอนิก",
+    "TrueType Font Collection" : "ชุดแบบอักษรประเภท TrueType",
+    "Web Open Font Format" : "แบบอักษร WOFF สำหรับเว็บไซท์",
+    "GPX geographic data" : "ข้อมูลภูมิศาสตร์แบบ GPX",
+    "Gzip archive" : "ข้อมูลบีบอัดแบบ Gzip",
+    "Adobe Illustrator document" : "เอกสาร Adobe Illustrator",
+    "Java source code" : "โค้ดต้นฉบับภาษา Java",
+    "JavaScript source code" : "โค้ดต้นฉบับภาษา JavaScript",
+    "JSON document" : "เอกสาร JSON",
+    "Microsoft Access database" : "ฐานข้อมูล Microsoft Access",
+    "Microsoft OneNote document" : "เอกสาร Microsoft OneNote",
     "Unknown" : "ไม่ทราบ",
-    "unknown text" : "ข้อความที่ไม่รู้จัก",
-    "Hello world!" : "สวัสดีทุกคน!",
-    "sunny" : "แดดมาก",
-    "Hello {name}, the weather is {weather}" : "สวัสดี {name} สภาพอากาศวันนี้มี{weather}",
-    "Hello {name}" : "สวัสดี {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>ผลลัพธ์การค้นหาของคุณ<script>alert(1)</script></strong>",
-    "new" : "ใหม่",
-    "_download %n file_::_download %n files_" : ["ดาวน์โหลด %n ไฟล์"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "กำลังดำเนินการอัปเกรด หากออกจากหน้านี้อาจเกิดปัญหาในบางสภาพแวดล้อม",
     "Update to {version}" : "อัปเดตเป็น {version}",
     "An error occurred." : "เกิดข้อผิดพลาด",
@@ -98,7 +109,6 @@ OC.L10N.register(
     "Search in current app" : "ค้นหาในแอปปัจจุบัน",
     "Clear search" : "ล้างการค้นหา",
     "Search everywhere" : "ค้นหาในทุกที่",
-    "Searching …" : "กำลังค้นหา …",
     "Start typing to search" : "เริ่มพิมพ์เพื่อค้นหา",
     "Today" : "วันนี้",
     "Last 7 days" : "ภายใน 7 วัน",
@@ -112,7 +122,6 @@ OC.L10N.register(
     "Results" : "ผลลัพธ์",
     "Load more results" : "โหลดผลลัพธ์เพิ่มเติม",
     "Log in" : "เข้าสู่ระบบ",
-    "Logging in …" : "กำลังเข้าสู่ระบบ ...",
     "Log in to {productName}" : "เข้าสู่ระบบไปยัง {productName}",
     "Wrong login or password." : "ล็อกอินหรือรหัสผ่านไม่ถูกต้อง",
     "This account is disabled" : "บัญชีนี้ถูกปิดใช้งาน",
@@ -141,21 +150,16 @@ OC.L10N.register(
     "Resetting password" : "กำลังตั้งรหัสผ่านใหม่",
     "Distraction free note taking app." : "แอปจดโน้ตแบบไร้สิ่งรบกวน",
     "Recommended apps" : "แอปแนะนำ",
-    "Loading apps …" : "กำลังโหลดแอป …",
     "Could not fetch list of apps from the App Store." : "ไม่สามารถดึงรายการแอปจากร้านค้าแอป",
     "App download or installation failed" : "การดาวน์โหลดหรือติดตั้งแอปล้มเหลว",
     "Cannot install this app because it is not compatible" : "ไม่สามารถติดตั้งแอปนี้ เนื่องจากแอปนี้เข้ากันไม่ได้",
     "Cannot install this app" : "ไม่สามารถติดตั้งแอปนี้",
     "Skip" : "ข้าม",
-    "Installing apps …" : "กำลังติดตั้งแอป …",
     "Install recommended apps" : "ติดตั้งแอปแนะนำ",
     "Avatar of {displayName}" : "อวาตาร์ของ {displayName}",
     "Settings menu" : "เมนูการตั้งค่า",
-    "Loading your contacts …" : "กำลังโหลดรายชื่อผู้ติดต่อของคุณ …",
-    "Looking for {term} …" : "กำลังค้นหา {term} …",
     "Search contacts" : "ค้นหารายชื่อ",
     "Reset search" : "รีเซ็ตการค้นหา",
-    "Search contacts …" : "ค้นหารายชื่อผู้ติดต่อ …",
     "Could not load your contacts" : "ไม่สามารถโหลดรายชื่อผู้ติดต่อ",
     "No contacts found" : "ไม่พบรายชื่อผู้ติดต่อ",
     "Show all contacts" : "แสดงรายชื่อทั้งหมด",
@@ -167,7 +171,6 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "เกิดข้อผิดพลาดขณะค้นหา {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "การค้นหาจะเริ่มนับจากที่คุณเริ่มพิมพ์ และสามารถเลือกผลลัพธ์ด้วยปุ่มลูกศรได้",
     "Search for {name} only" : "ค้นหาเฉพาะ {name} เท่านั้น",
-    "Loading more results …" : "กำลังโหลดผลลัพธ์เพิ่มเติม …",
     "Forgot password?" : "ลืมรหัสผ่าน?",
     "Back to login form" : "กลับสู่แบบฟอร์มเข้าสู่ระบบ",
     "Back" : "ย้อนกลับ",
@@ -187,7 +190,6 @@ OC.L10N.register(
     "Database tablespace" : "พื้นที่ตารางในฐานข้อมูล",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "โปรดระบุหมายเลขพอร์ตพร้อมชื่อโฮสต์ (เช่น localhost:5432)",
     "Database host" : "โฮสต์ฐานข้อมูล",
-    "Installing …" : "กำลังติดตั้ง …",
     "Install" : "ติดตั้ง",
     "Need help?" : "ต้องการความช่วยเหลือ?",
     "See the documentation" : "ดูเอกสารประกอบ",
@@ -196,7 +198,6 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "เบราว์เซอร์ของคุณไม่ได้รับการสนับสนุน กรุณาอัปเกรดเป็นรุ่นที่ใหม่กว่าหรือเบราว์เซอร์ที่สนับสนุน",
     "Continue with this unsupported browser" : "ดำเนินการต่อด้วยเบราว์เซอร์นี้ที่ไม่สนับสนุน",
     "Supported versions" : "รุ่นที่สนับสนุน",
-    "Search {types} …" : "ค้นหา {types} …",
     "Choose {file}" : "เลือก {file}",
     "Choose" : "เลือก",
     "Copy to {target}" : "คัดลอกไปยัง {target}",
@@ -216,7 +217,6 @@ OC.L10N.register(
     "(all selected)" : "(เลือกทั้งหมด)",
     "({count} selected)" : "(เลือก {count} รายการ)",
     "Error loading file exists template" : "เกิดข้อผิดพลาดขณะโหลดไฟล์เทมเพลตที่มีอยู่",
-    "Saving …" : "กำลังบันทึก …",
     "seconds ago" : "วินาทีที่แล้ว",
     "Connection to server lost" : "การเชื่อมต่อไปยังเซิร์ฟเวอร์สูญหาย",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["เกิดปัญหาขณะโหลดหน้าเว็บ จะโหลดหน้าเว็บใหม่ใน %n วินาที"],
@@ -231,8 +231,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "พิมพ์เพื่อค้นหาโครงการที่มีอยู่",
     "New in" : "ใหม่ใน",
     "View changelog" : "ดูบันทึกการเปลี่ยนแปลง",
-    "No action available" : "ไม่มีการกระทำที่ใช้ได้",
-    "Error fetching contact actions" : "เกิดข้อผิดพลาดในการดึงการกระทำรายชื่อ",
     "Close \"{dialogTitle}\" dialog" : "ปิดกล่องโต้ตอบ \"{dialogTitle}\"",
     "Personal" : "ส่วนตัว",
     "Accounts" : "บัญชี",
@@ -315,20 +313,33 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "เซิร์ฟเวอร์ %s นี้อยู่ในโหมดการบำรุงรักษา ซึ่งอาจใช้เวลาสักครู่",
     "This page will refresh itself when the instance is available again." : "หน้านี้จะรีเฟรชตัวเองเมื่อเซิร์ฟเวอร์สามารถใช้ได้อีกครั้ง",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "ติดต่อผู้ดูแลระบบของคุณหากข้อความนี้ยังคงอยู่หรือปรากฏโดยไม่คาดคิด",
-    "No temporary profile picture available, try again" : "ไม่มีรูปภาพโปรไฟล์ชั่วคราว กรุณาลองใหม่อีกครั้ง",
-    "No crop data provided" : "ไม่ได้ระบุข้อมูลการครอบตัด",
-    "No valid crop data provided" : "ไม่ได้ระบุข้อมูลการครอบตัดที่ถูกต้อง",
-    "Crop is not square" : "การครอบตัดไม่เป็นสี่เหลี่ยม",
     "Error occurred while checking server setup" : "เกิดข้อผิดพลาดขณะตรวจสอบการติดตั้งเซิร์ฟเวอร์",
     "For more details see the {linkstart}documentation ↗{linkend}." : "สำหรับข้อมูลเพิ่มเติม โปรดดู{linkstart}เอกสารประกอบ ↗{linkend}",
-    "You have not added any info yet" : "คุณยังไม่ได้เพิ่มข้อมูลใด ๆ",
-    "{user} has not added any info yet" : "{user} ยังไม่ได้เพิ่มข้อมูลใด ๆ",
-    "Edit Profile" : "แก้ไขโปรไฟล์",
+    "unknown text" : "ข้อความที่ไม่รู้จัก",
+    "Hello world!" : "สวัสดีทุกคน!",
+    "sunny" : "แดดมาก",
+    "Hello {name}, the weather is {weather}" : "สวัสดี {name} สภาพอากาศวันนี้มี{weather}",
+    "Hello {name}" : "สวัสดี {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>ผลลัพธ์การค้นหาของคุณ<script>alert(1)</script></strong>",
+    "new" : "ใหม่",
+    "_download %n file_::_download %n files_" : ["ดาวน์โหลด %n ไฟล์"],
+    "Searching …" : "กำลังค้นหา …",
+    "Logging in …" : "กำลังเข้าสู่ระบบ ...",
+    "Loading apps …" : "กำลังโหลดแอป …",
+    "Installing apps …" : "กำลังติดตั้งแอป …",
+    "Loading your contacts …" : "กำลังโหลดรายชื่อผู้ติดต่อของคุณ …",
+    "Looking for {term} …" : "กำลังค้นหา {term} …",
+    "Search contacts …" : "ค้นหารายชื่อผู้ติดต่อ …",
+    "Loading more results …" : "กำลังโหลดผลลัพธ์เพิ่มเติม …",
+    "Search {types} …" : "ค้นหา {types} …",
+    "Saving …" : "กำลังบันทึก …",
     "Very weak password" : "รหัสผ่านระดับต่ำมาก",
     "Weak password" : "รหัสผ่านระดับต่ำ",
     "So-so password" : "รหัสผ่านระดับปกติ",
     "Good password" : "รหัสผ่านระดับดี",
     "Strong password" : "รหัสผ่านระดับดีมาก",
+    "No action available" : "ไม่มีการกระทำที่ใช้ได้",
+    "Error fetching contact actions" : "เกิดข้อผิดพลาดในการดึงการกระทำรายชื่อ",
     "Non-existing tag #{tag}" : "แท็ก #{tag} ไม่มีอยู่",
     "Restricted" : "ถูกจำกัด",
     "Invisible" : "มองไม่เห็น",
@@ -336,14 +347,13 @@ OC.L10N.register(
     "Rename" : "เปลี่ยนชื่อ",
     "Collaborative tags" : "แท็กแบบทำงานร่วมกัน",
     "No tags found" : "ไม่พบแท็ก",
-    "Profile not found" : "ไม่พบโปรไฟล์",
-    "The profile does not exist." : "โปรไฟล์นี้ไม่มีอยู่",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "ไดเรกทอรี data และไฟล์ของคุณอาจเข้าถึงได้จากอินเทอร์เน็ต เพราะไฟล์ .htaccess ไม่ทำงาน",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "สำหรับวิธีการกำหนดค่าเซิร์ฟเวอร์ของคุณอย่างถูกต้อง โปรดดู<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">เอกสารประกอบ</a>",
     "Show password" : "แสดงรหัสผ่าน",
     "Toggle password visibility" : "เปิด-ปิด การมองเห็นรหัสผ่าน",
     "Configure the database" : "ตั้งค่าฐานข้อมูล",
     "Only %s is available." : "เฉพาะ %s สามารถใช้ได้",
-    "Database account" : "บัญชีฐานข้อมูล"
+    "Database account" : "บัญชีฐานข้อมูล",
+    "Installing …" : "กำลังติดตั้ง …"
 },
 "nplurals=1; plural=0;");
