@@ -196,14 +196,6 @@ OC.L10N.register(
     "Matroska video" : "Matroska 視頻",
     "Windows Media video" : "Windows Media 視頻",
     "AVI video" : "AVI 視頻",
-    "unknown text" : "文字不詳",
-    "Hello world!" : "哈囉，世界！",
-    "sunny" : "晴朗的",
-    "Hello {name}, the weather is {weather}" : "哈囉 {name}，今日天氣 {weather}",
-    "Hello {name}" : "哈囉 {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>以下是您的搜尋結果<script>警告（1）</script></strong>",
-    "new" : "新",
-    "_download %n file_::_download %n files_" : ["下載 %n 個檔案"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "正在更新，在某些狀況下，離開本頁面可能會導致更新中斷",
     "Update to {version}" : "更新到 {version}",
     "An error occurred." : "發生錯誤。",
@@ -233,7 +225,6 @@ OC.L10N.register(
     "Search in current app" : "在目前的應用程式中搜尋",
     "Clear search" : "清除搜尋",
     "Search everywhere" : "到處搜尋",
-    "Searching …" : "正在搜尋……",
     "Start typing to search" : "輸入文字以檢索",
     "No matching results" : "無相符結果",
     "Today" : "今日",
@@ -254,7 +245,7 @@ OC.L10N.register(
     "Load more results" : "載入更多結果",
     "Search in" : "搜尋",
     "Log in" : "登入",
-    "Logging in …" : "正在登入 …",
+    "Logging in …" : "正在登入 …",
     "Log in to {productName}" : "登入至 {productName}",
     "Wrong login or password." : "登入名稱或密碼錯誤。",
     "This account is disabled" : "此帳戶已停用",
@@ -291,21 +282,16 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "基於 Collabora Online 構建的協作文件、試算表和演講文稿。",
     "Distraction free note taking app." : "無干擾的筆記應用程式。",
     "Recommended apps" : "推薦的應用程式",
-    "Loading apps …" : "正在載入應用程式 …",
     "Could not fetch list of apps from the App Store." : "無法從 App Store 擷取應用程式清單。",
     "App download or installation failed" : "應用程式下載或是安裝失敗",
     "Cannot install this app because it is not compatible" : "由於不兼容，無法安裝此應用程式",
     "Cannot install this app" : "無法安裝此應用程式",
     "Skip" : "略過",
-    "Installing apps …" : "正在安裝應用程式…",
     "Install recommended apps" : "安裝推薦的應用程式",
     "Avatar of {displayName}" : "{displayName} 的虛擬化身",
     "Settings menu" : "設定選項單",
-    "Loading your contacts …" : "正在載入聯絡人…",
-    "Looking for {term} …" : "正在搜尋 {term} …",
     "Search contacts" : "搜尋聯絡人",
     "Reset search" : "重設搜尋",
-    "Search contacts …" : "搜尋聯絡人…",
     "Could not load your contacts" : "無法載入您的聯絡人",
     "No contacts found" : "找不到聯絡人",
     "Show all contacts" : "顯示所有聯絡人",
@@ -317,7 +303,6 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "搜尋 {type} 時發生錯誤",
     "Search starts once you start typing and results may be reached with the arrow keys" : "一旦您開始輸入，搜尋就會開始，您可以使用方向鍵到達結果",
     "Search for {name} only" : "只搜尋 {name}",
-    "Loading more results …" : "正在載入更多結果...",
     "Forgot password?" : "忘記密碼？",
     "Back to login form" : "回到登入表格",
     "Back" : "返回",
@@ -361,7 +346,6 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "請指定連接埠號與主機名稱（例如：localhost:5432）。",
     "Database host" : "數據庫主機",
     "localhost" : "localhost",
-    "Installing …" : "正在安裝 …",
     "Install" : "安裝",
     "Need help?" : "需要協助嗎？",
     "See the documentation" : "閱讀說明文件",
@@ -370,7 +354,6 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "不支援您的瀏覽器。請升級至較新或受支援的版本。",
     "Continue with this unsupported browser" : "繼續使用此不受支援的瀏覽器",
     "Supported versions" : "支援的版本",
-    "Search {types} …" : "搜尋 {types} 中 …",
     "Choose {file}" : "選擇 {file}",
     "Choose" : "選擇",
     "Copy to {target}" : "複製到 {target}",
@@ -390,7 +373,7 @@ OC.L10N.register(
     "(all selected)" : "（已全選）",
     "({count} selected)" : "（已選擇 {count} 項）",
     "Error loading file exists template" : "載入已存在的模板時發生錯誤",
-    "Saving …" : "儲存中 ...",
+    "Saving …" : "儲存中 ...",
     "seconds ago" : "幾秒前",
     "Connection to server lost" : "伺服器連線中斷",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["載入頁面時出錯，%n 秒後重新整理"],
@@ -405,8 +388,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "搜尋現有專案",
     "New in" : "新加入",
     "View changelog" : "檢視版本更新紀錄",
-    "No action available" : "沒有可用的操作",
-    "Error fetching contact actions" : "擷取聯絡人時發生錯誤",
     "Close \"{dialogTitle}\" dialog" : "關閉 \"{dialogTitle}\" 對話",
     "Email length is at max (255)" : "電子郵件已達到最大長度（255 個字元）",
     "Clipboard not available, please copy manually" : "剪貼板不可用，請人手複製",
@@ -494,23 +475,34 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "此 %s 實例目前處於維護模式，可能需要一段時間才能完成。",
     "This page will refresh itself when the instance is available again." : "安裝恢復可用之後，本頁會自動重新整理",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "若這個訊息持續出現，請聯絡系統管理員。",
-    "No temporary profile picture available, try again" : "沒有可用的臨時個人資料圖片，請再試一次",
-    "No crop data provided" : "未提供剪裁設定",
-    "No valid crop data provided" : "未提供有效的剪裁設定",
-    "Crop is not square" : "剪裁設定不是正方形",
     "Error occurred while checking server setup" : "檢查伺服器設定時發生錯誤",
     "For more details see the {linkstart}documentation ↗{linkend}." : "有關更多細節，請參見 {linkstart} 說明書↗{linkend}。",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "對話、視訊電話、螢幕分享、線上會議與網路研討會 - 實現於你的瀏覽器與手機 apps 之中。",
-    "You have not added any info yet" : "您尚未新增任何資訊",
-    "{user} has not added any info yet" : "{user} 尚未新增任何資訊",
-    "Error opening the user status modal, try hard refreshing the page" : "打開用戶狀態模式時出錯，請嘗試刷新頁面",
-    "Edit Profile" : "編輯個人設定",
-    "The headline and about sections will show up here" : "標題與關於部份將在此顯示",
+    "unknown text" : "文字不詳",
+    "Hello world!" : "哈囉，世界！",
+    "sunny" : "晴朗的",
+    "Hello {name}, the weather is {weather}" : "哈囉 {name}，今日天氣 {weather}",
+    "Hello {name}" : "哈囉 {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>以下是您的搜尋結果<script>警告（1）</script></strong>",
+    "new" : "新",
+    "_download %n file_::_download %n files_" : ["下載 %n 個檔案"],
+    "Direct link copied to clipboard" : "直接連結已複製到剪貼簿",
+    "Searching …" : "正在搜尋……",
+    "Logging in …" : "正在登入 …",
+    "Loading apps …" : "正在載入應用程式 …",
+    "Installing apps …" : "正在安裝應用程式…",
+    "Loading your contacts …" : "正在載入聯絡人…",
+    "Looking for {term} …" : "正在搜尋 {term} …",
+    "Search contacts …" : "搜尋聯絡人…",
+    "Loading more results …" : "正在載入更多結果...",
+    "Search {types} …" : "搜尋 {types} 中 …",
+    "Saving …" : "儲存中 ...",
     "Very weak password" : "密碼安全性極弱",
     "Weak password" : "密碼安全性弱",
     "So-so password" : "密碼安全性普通",
     "Good password" : "密碼安全性佳",
     "Strong password" : "密碼強度極佳",
+    "No action available" : "沒有可用的操作",
+    "Error fetching contact actions" : "擷取聯絡人時發生錯誤",
     "Non-existing tag #{tag}" : "不存在的標籤 #{tag}",
     "Restricted" : "受限",
     "Invisible" : "隱藏",
@@ -518,8 +510,6 @@ OC.L10N.register(
     "Rename" : "重新命名",
     "Collaborative tags" : "協作標籤",
     "No tags found" : "查無標籤",
-    "Profile not found" : "找不到個人資料",
-    "The profile does not exist." : "個人資料不存在",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "您的資料目錄可能可以從互聯網存取，因為 .htaccess 不起作用。",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "有關如何正確配置伺服器的信息，請參閱<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">說明書</a>。",
     "<strong>Create an admin account</strong>" : "<strong>創建管理員帳戶</strong>",
@@ -530,6 +520,6 @@ OC.L10N.register(
     "Configure the database" : "設定數據庫",
     "Only %s is available." : "僅 %s 可使用。",
     "Database account" : "數據庫帳戶",
-    "Direct link copied to clipboard" : "直接連結已複製到剪貼簿"
+    "Installing …" : "正在安裝 …"
 },
 "nplurals=1; plural=0;");
