@@ -197,14 +197,6 @@ OC.L10N.register(
     "Matroska video" : "Matroska 視訊",
     "Windows Media video" : "Windows 媒體視訊",
     "AVI video" : "AVI 視訊",
-    "unknown text" : "未知的文字",
-    "Hello world!" : "哈囉，世界！",
-    "sunny" : "晴朗",
-    "Hello {name}, the weather is {weather}" : "哈囉 {name}，今天天氣{weather}",
-    "Hello {name}" : "哈囉 {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>以下是您的搜尋結果<script>警告(1)</script></strong>",
-    "new" : "新",
-    "_download %n file_::_download %n files_" : ["下載 %n 個檔案"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "正在更新，離開本頁面在某些情況下可能會導致更新中斷。",
     "Update to {version}" : "更新到 {version}",
     "An error occurred." : "發生錯誤。",
@@ -234,7 +226,7 @@ OC.L10N.register(
     "Search in current app" : "在目前的應用程式中搜尋",
     "Clear search" : "清除搜尋",
     "Search everywhere" : "到處搜尋",
-    "Searching …" : "正在搜尋…",
+    "Searching …" : "正在搜尋 ……",
     "Start typing to search" : "開始輸入以搜尋",
     "Minimum search length is {minSearchLength} characters" : "最小搜尋長度為 {minSearchLength} 個字元",
     "No matching results" : "無相符結果",
@@ -256,7 +248,7 @@ OC.L10N.register(
     "Load more results" : "載入更多結果",
     "Search in" : "搜尋條件",
     "Log in" : "登入",
-    "Logging in …" : "正在登入…",
+    "Logging in …" : "正在登入……",
     "Log in to {productName}" : "登入 {productName}",
     "Wrong login or password." : "錯誤的帳號或密碼。",
     "This account is disabled" : "此帳號已停用",
@@ -293,21 +285,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "使用 Collabora Online 建置的文件、試算表、簡報協作工具。",
     "Distraction free note taking app." : "無干擾的筆記應用程式。",
     "Recommended apps" : "推薦的應用程式",
-    "Loading apps …" : "正在載入應用程式…",
+    "Loading apps …" : "正在載入應用程式 ……",
     "Could not fetch list of apps from the App Store." : "無法從應用程式商店擷取應用程式清單。",
     "App download or installation failed" : "應用程式下載或安裝失敗",
     "Cannot install this app because it is not compatible" : "由於不相容，無法安裝此應用程式",
     "Cannot install this app" : "無法安裝應用程式",
     "Skip" : "跳過",
-    "Installing apps …" : "正在安裝應用程式…",
+    "Installing apps …" : "正在安裝應用程式 ……",
     "Install recommended apps" : "安裝推薦的應用程式",
     "Avatar of {displayName}" : "{displayName} 的頭像",
     "Settings menu" : "設定選單",
-    "Loading your contacts …" : "正在載入聯絡人…",
-    "Looking for {term} …" : "正在搜尋 {term}…",
+    "Loading your contacts …" : "正在載入您的聯絡人 ……",
+    "Looking for {term} …" : "正在尋找 {term} ……",
     "Search contacts" : "搜尋聯絡人",
     "Reset search" : "重設搜尋",
-    "Search contacts …" : "搜尋聯絡人…",
+    "Search contacts …" : "搜尋聯絡人 ……",
     "Could not load your contacts" : "無法載入您的聯絡人",
     "No contacts found" : "查無聯絡人",
     "Show all contacts" : "顯示所有聯絡人",
@@ -319,7 +311,7 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "搜尋 {type} 時發生錯誤",
     "Search starts once you start typing and results may be reached with the arrow keys" : "您一開始輸入，搜尋就會開始，可以使用方向鍵切換搜尋結果",
     "Search for {name} only" : "僅搜尋 {name}",
-    "Loading more results …" : "正在載入更多結果…",
+    "Loading more results …" : "正在載入更多結果 ……",
     "Forgot password?" : "忘記密碼？",
     "Back to login form" : "返回登入表單",
     "Back" : "返回",
@@ -349,6 +341,7 @@ OC.L10N.register(
     "Storage & database" : "儲存空間和資料庫",
     "Data folder" : "資料儲存位置",
     "Database configuration" : "資料庫組態",
+    "Database type" : "資料庫類型",
     "Only {firstAndOnlyDatabase} is available." : "僅 {firstAndOnlyDatabase} 可用。",
     "Install and activate additional PHP modules to choose other database types." : "安裝並啟用相關 PHP 模組來選擇其他資料庫類型。",
     "For more details check out the documentation." : "請參閱說明文件了解更多細節。",
@@ -356,6 +349,7 @@ OC.L10N.register(
     "You chose SQLite as database." : "您選擇了 SQLite 作為資料庫。",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite 只適用於小型或開發中站台。對於正式上線用途，我們建議改用其他資料庫後端。",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "若您會使用桌面版或手機版客戶端同步檔案，則強烈不建議使用 SQLite。",
+    "Database connection" : "資料庫連線",
     "Database user" : "資料庫使用者",
     "Database password" : "資料庫密碼",
     "Database name" : "資料庫名稱",
@@ -363,7 +357,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "請指定連接埠號與主機名稱（例如：localhost:5432）。",
     "Database host" : "資料庫主機",
     "localhost" : "localhost",
-    "Installing …" : "正在安裝…",
+    "Installing …" : "正在安裝 ……",
     "Install" : "安裝",
     "Need help?" : "需要協助嗎？",
     "See the documentation" : "參閱說明文件",
@@ -372,7 +366,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "不支援您的瀏覽器。請升級至較新或受支援的版本。",
     "Continue with this unsupported browser" : "繼續使用不受支援的瀏覽器",
     "Supported versions" : "支援的版本",
-    "Search {types} …" : "搜尋 {types} 中…",
+    "Search {types} …" : "搜尋 {types} ……",
     "Choose {file}" : "選擇 {file}",
     "Choose" : "選擇",
     "Copy to {target}" : "複製到 {target}",
@@ -392,7 +386,7 @@ OC.L10N.register(
     "(all selected)" : "（已全選）",
     "({count} selected)" : "（已選取 {count} 項）",
     "Error loading file exists template" : "載入已存在的範本時發生錯誤",
-    "Saving …" : "正在儲存…",
+    "Saving …" : "正在儲存 …",
     "seconds ago" : "幾秒前",
     "Connection to server lost" : "伺服器連線中斷",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["載入頁面時發生問題，%n 秒後重新整理"],
@@ -407,8 +401,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "搜尋現有專案",
     "New in" : "新加入",
     "View changelog" : "檢視版本更新紀錄",
-    "No action available" : "沒有可用的動作",
-    "Error fetching contact actions" : "擷取聯絡人時發生錯誤",
     "Close \"{dialogTitle}\" dialog" : "關閉「{dialogTitle}」對話方塊",
     "Email length is at max (255)" : "電子郵件長度最長 (255)",
     "Clipboard not available, please copy manually" : "無法使用剪貼簿，請手動複製",
@@ -496,23 +488,34 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "這個 %s 站台目前處於維護模式，需要一段時間恢復。",
     "This page will refresh itself when the instance is available again." : "在站台恢復可用之後，本頁會自動重新整理。",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "若這個訊息持續出現，請聯絡系統管理員。",
-    "No temporary profile picture available, try again" : "沒有臨時用的個人檔案圖片，請再試一次",
-    "No crop data provided" : "未設定剪裁",
-    "No valid crop data provided" : "未提供有效的剪裁設定",
-    "Crop is not square" : "剪裁設定不是正方形",
     "Error occurred while checking server setup" : "檢查伺服器設定時發生錯誤",
     "For more details see the {linkstart}documentation ↗{linkend}." : "詳細資訊請參閱 {linkstart} 文件 ↗{linkend}。",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "對話、視訊電話、螢幕分享、線上會議、網路研討會等 - 在您的瀏覽器與手機應用程式之中實現。",
-    "You have not added any info yet" : "您尚未新增任何資訊",
-    "{user} has not added any info yet" : "{user} 尚未新增任何資訊",
-    "Error opening the user status modal, try hard refreshing the page" : "開啟使用者狀態的模組時發生問題，嘗試重新整理頁面",
-    "Edit Profile" : "編輯個人檔案",
-    "The headline and about sections will show up here" : "標題與關於區段將在此顯示",
+    "unknown text" : "未知的文字",
+    "Hello world!" : "哈囉，世界！",
+    "sunny" : "晴朗",
+    "Hello {name}, the weather is {weather}" : "哈囉 {name}，今天天氣{weather}",
+    "Hello {name}" : "哈囉 {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>以下是您的搜尋結果<script>警告(1)</script></strong>",
+    "new" : "新",
+    "_download %n file_::_download %n files_" : ["下載 %n 個檔案"],
+    "Direct link copied to clipboard" : "直接連結已複製到剪貼簿",
+    "Searching …" : "正在搜尋…",
+    "Logging in …" : "正在登入…",
+    "Loading apps …" : "正在載入應用程式…",
+    "Installing apps …" : "正在安裝應用程式…",
+    "Loading your contacts …" : "正在載入聯絡人…",
+    "Looking for {term} …" : "正在搜尋 {term}…",
+    "Search contacts …" : "搜尋聯絡人…",
+    "Loading more results …" : "正在載入更多結果…",
+    "Search {types} …" : "搜尋 {types} 中…",
+    "Saving …" : "正在儲存…",
     "Very weak password" : "密碼安全性極弱",
     "Weak password" : "密碼安全性弱",
     "So-so password" : "密碼安全性普通",
     "Good password" : "密碼安全性佳",
     "Strong password" : "密碼安全性極佳",
+    "No action available" : "沒有可用的動作",
+    "Error fetching contact actions" : "擷取聯絡人時發生錯誤",
     "Non-existing tag #{tag}" : "不存在的標籤 #{tag}",
     "Restricted" : "受限",
     "Invisible" : "隱藏",
@@ -520,8 +523,6 @@ OC.L10N.register(
     "Rename" : "重新命名",
     "Collaborative tags" : "協作標籤",
     "No tags found" : "找不到標籤",
-    "Profile not found" : "找不到個人檔案",
-    "The profile does not exist." : "個人檔案不存在。",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "您的資料目錄與檔案似乎可從網際網路存取，因為 .htaccess 檔案並未生效。",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "請參閱<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">說明文件</a>來瞭解如何正確設定您的伺服器組態。",
     "<strong>Create an admin account</strong>" : "<strong>建立管理員帳號</strong>",
@@ -532,6 +533,6 @@ OC.L10N.register(
     "Configure the database" : "設定資料庫組態",
     "Only %s is available." : "剩下 %s 可使用。",
     "Database account" : "資料庫帳號",
-    "Direct link copied to clipboard" : "直接連結已複製到剪貼簿"
+    "Installing …" : "正在安裝…"
 },
 "nplurals=1; plural=0;");
