@@ -35,14 +35,16 @@ p($theme->getTitle());
 		<?php emit_script_loading_tags($_); ?>
 		<?php print_unescaped($_['headers']); ?>
 	</head>
-	<body id="<?php p($_['bodyid']);?>">
+	<body id="<?php p($_['bodyid']);?>" <?php foreach ($_['enabledThemes'] as $themeId) {
+		p("data-theme-$themeId ");
+	}?> data-themes="<?php p(join(',', $_['enabledThemes'])) ?>">
 		<?php include 'layout.noscript.warning.php'; ?>
 		<?php include 'layout.initial-state.php'; ?>
 		<div class="wrapper">
 			<div class="v-align">
 				<?php if ($_['bodyid'] === 'body-login'): ?>
 					<header>
-						<div id="header">
+						<div id="header" class="header-guest">
 							<div class="logo"></div>
 						</div>
 					</header>
