@@ -93,6 +93,8 @@ OC.L10N.register(
     "Destination does not exist" : "Одредиште не постоји",
     "Destination is not creatable" : "Одредиште не може да се креира",
     "Dot files are not allowed" : "Фајлови са почетном тачком нису дозвољени",
+    "%1$s (renamed)" : "%1$s (преименован)",
+    "renamed file" : "преименован фајл",
     "\"%1$s\" is a forbidden file or folder name." : "„%1$s” је забрањено име фајла или фолдера.",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "„%1$s” је забрањени префикс имена фајла или фолдера.",
     "\"%1$s\" is not allowed inside a file or folder name." : "„%1$s” није дозвољено у имену фајла или фолдера.",
@@ -127,6 +129,8 @@ OC.L10N.register(
     "Settings" : "Поставке",
     "Log out" : "Одјава",
     "Accounts" : "Налози",
+    "Bluesky" : "Bluesky",
+    "View %s on Bluesky" : "Прикажи %s на Bluesky",
     "Email" : "Е-пошта",
     "Mail %s" : "Пошта %s",
     "Fediverse" : "Fediverse",
@@ -142,7 +146,7 @@ OC.L10N.register(
     "About" : "О програму",
     "Display name" : "Име за приказ",
     "Headline" : "Наслов",
-    "Organisation" : "Организација",
+    "Organization" : "Организација",
     "Role" : "Улога",
     "Pronouns" : "Заменице",
     "Unknown account" : "Непознати налог",
@@ -201,7 +205,7 @@ OC.L10N.register(
     "Path is already shared with this group" : "Путања се већ дели са овом групом",
     "Link sharing is not allowed" : "Није дозвољено дељење линком",
     "Public upload is not allowed" : "Није дозвољено јавно отпремање",
-    "Path contains files shared with you" : "Путања садржи фајлове који су подељени са вама",
+    "You cannot share a folder that contains other shares" : "Не можете да делите фолдер који садржи друга дељења",
     "Sharing is disabled" : "Дељење је искључено",
     "Sharing is disabled for you" : "Дељење је за вас искључено",
     "Cannot share with the share owner" : "Не може да се дели са власником дељења",
@@ -273,6 +277,7 @@ OC.L10N.register(
     "A valid Login must be provided" : "Морате да унесете исправно име за пријаву",
     "Login contains whitespace at the beginning or at the end" : "Име за пријаву садржи белине на почетку или на крају",
     "Login must not consist of dots only" : "Име за пријаву не може да се састоји само од тачака",
+    "Username is too long" : "Корисничко име је сувише дугачко",
     "Login is invalid because files already exist for this user" : "Име за пријаву није исправно пошто већ постоје фајлови овог корисника",
     "Account disabled" : "Налог је искључен",
     "Login canceled by app" : "Пријава отказана од стране апликације",
@@ -285,8 +290,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Не може да се упише у „config директоријум.",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Ово обично може да се поправи тако што се веб серверу дозволи право уписа у config директоријум. Погледајте %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Или, ако пре желите да задржите config.php да је само за читање, поставите опцију \"config_is_read_only\" на true у њему самом. Погледајте %s",
-    "Cannot write into \"apps\" directory." : "Не може да се упише у „apps” директоријум.",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Ово обично може да се поправи тако што се веб серверу дозволи право уписа у apps директоријум или тако што се искључи Продавница апликација у config фајлу.",
     "Cannot create \"data\" directory." : "Не може да се креира „data” директоријум.",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Ово обично може да се поправи тако што се веб серверу дозволи право уписа у корени директоријум. Погледајте %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Проблем са дозволама обично може да се поправи тако што се веб серверу дозволи право уписа у корени директоријум. Погледајте %s.",
@@ -297,8 +300,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Замолите администратора вашег сервера да инсталира тај модул.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP поставка „%s“ није постављена на „%s“.",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Некстклауд ће прорадити поново када прилагодите ово подашавање у php.ini фајлу",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> је постављено на <code>%s</code> уместо на очекивану вредност <code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Да бисте исправили овај проблем, поставите <code>mbstring.func_overload</code> на <code>0</code> у свом php.ini фајлу.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP је очигледно подешен да склања уметнуте doc блокове. То ће учинити неколико кључних апликација недоступним.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ово је вероватно изазвано кешом или акцелератором као што су ЗендОПкеш или еАкцелератор.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP модули су инсталирани али се и даље воде као недостајући?",
@@ -323,26 +324,48 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Складиште привремено није  доступно",
     "Storage connection timeout. %s" : "Истекло је време за повезивање на складиште. %s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Ако желите да се ова провера изврши, морате обезбедити да ваш веб сервер може да се повеже на самог себе. То значи да мора бити у стању да разреши и да се повеже барем на један од својих `trusted_domains` или `overwrite.cli.url`. Ова грешка може да буде резултат DNS неподударања на страни сервера или одлазно правило заштитног зида.",
+    "Analyze images" : "Анализирај слике",
+    "Ask a question about the given images." : "Поставите питање у вези са датим сликама.",
+    "Images" : "Слике",
+    "Images to ask a question about" : "Слике о којим се постављају питања",
+    "Question" : "Питање",
+    "What to ask about the images." : "Шта да се пита у вези са сликама.",
+    "Generated response" : "Генерисани одговор",
+    "The answer to the question" : "Одговор на питање",
+    "Audio chat" : "Аудио чет",
+    "Voice chat with the assistant" : "Гласовни чет са асистентом",
+    "System prompt" : "Кориснички захтев",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Дефинишите правила и претпоставке које би асистент требало да следи током разговора.",
+    "Chat voice message" : "Чет говорна порука",
+    "Describe a task that you want the assistant to do or ask a question." : "Опишите задатак који желите да асистент обави или поставите питање.",
+    "Chat history" : "Историју чета",
+    "The history of chat messages before the current message, starting with a message by the user." : "Историја чет порука пре текуће поруке, почевши са поруком корисника.",
+    "Input transcript" : "Транскрипт уноса",
+    "Transcription of the audio input" : "Транскрипт аудио улаза",
+    "Response voice message" : "Гласовна порука одговора",
+    "The generated voice response as part of the conversation" : "Генерисани гласовни одговор као део разговора",
+    "Output transcript" : "Транскрипт излаза",
+    "Transcription of the audio output" : "Транскрипција аудио излаза",
     "Transcribe audio" : "Транскрибуј звук",
     "Transcribe the things said in an audio" : "Транскрибује оно што се каже у звуку",
     "Audio input" : "Аудио улаз",
     "The audio to transcribe" : "Звук који треба да се транскрибује",
     "Transcription" : "Транскрипција",
     "The transcribed text" : "Транскрибовани текст",
-    "ContextAgent" : "КонтекстАгент",
-    "Chat with an agent" : "Ћаскај са агентом",
-    "Chat message" : "Чет порука",
-    "A chat message to send to the agent." : "Порука која треба да се пошаље агенту.",
+    "Chat by voice with an agent" : "Гласовни чет са агентом",
+    "Describe a task that you want the agent to do or ask a question." : "Опишите задатак који желите да агент обави или поставите питање.",
     "Confirmation" : "Потврда",
     "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Да ли да се потврде претходно затражене акције: 0 за одбијање и 1 за потврђивње.",
     "Conversation token" : "Жетон разговора",
     "A token representing the conversation." : "Жетон који представља разговор.",
-    "Generated response" : "Генерисани одговор",
-    "The response from the chat model." : "Одговор чет модела.",
     "The new conversation token" : "Нови жетон разговора",
     "Send this along with the next interaction." : "Пошаљи ово уз наредну интеракцију.",
     "Requested actions by the agent" : "Акције које је захтевао агент",
     "Actions that the agent would like to carry out in JSON format." : "Акције које би агент желео да изврши у JSON формату.",
+    "Chat with an agent" : "Ћаскај са агентом",
+    "Chat message" : "Чет порука",
+    "A chat message to send to the agent." : "Порука која треба да се пошаље агенту.",
+    "The response from the chat model." : "Одговор чет модела.",
     "Context write" : "Писање контекста",
     "Writes text in a given style based on the provided source material." : "Пише текст у датом стилу заснован на наведеном изворном материјалу.",
     "Writing style" : "Стил писања",
@@ -364,6 +387,11 @@ OC.L10N.register(
     "How many images to generate" : "Колико слика желите да се генерише",
     "Output images" : "Излазне слике",
     "The generated images" : "Генерисане слике",
+    "Generate speech" : "Генериши говор",
+    "Generate speech from a transcript" : "Генерише говор из транскрипта",
+    "Write transcript that you want the assistant to generate speech from" : "Напишите транскрипт из којег желите да асистент генерише говор",
+    "Output speech" : "Излазни говор",
+    "The generated speech" : "Генерисани говор",
     "Free text to text prompt" : "Произвољни текст као унос",
     "Runs an arbitrary prompt through a language model that returns a reply" : "Извршава произвољни захтев кроз језички модел који затим враћа одговор",
     "Describe a task that you want the assistant to do or ask a question" : "Опишите задатак који желите да обави асистент или поставите питање",
@@ -377,9 +405,6 @@ OC.L10N.register(
     "The rewritten text in the desired tone, written by the assistant:" : "Реформулисани текст у траженом тону који је написао асистент:",
     "Chat" : "Ћаскање",
     "Chat with the assistant" : "Ћаскање са асистентом",
-    "System prompt" : "Кориснички захтев",
-    "Define rules and assumptions that the assistant should follow during the conversation." : "Дефинишите правила и претпоставке које би асистент требало да следи током разговора.",
-    "Chat history" : "Историју чета",
     "The history of chat messages before the current message, starting with a message by the user" : "Историја чет порука пре текуће поруке, почевши са поруком корисника",
     "Response message" : "Порука одговора",
     "The generated response as part of the conversation" : "Генерисани  одговор као део разговора",
@@ -443,20 +468,11 @@ OC.L10N.register(
     "Generate headline" : "Генериши линију наслова",
     "Summarizes text by reducing its length without losing key information." : "Резимира текст тако што га скраћује без губитка кључних информација.",
     "Extracts topics from a text and outputs them separated by commas." : "Издваја теме из текста и исписује их раздвојене запетама.",
-    "Education Edition" : "Образовно издање",
-    "File name is a reserved word" : "Назив фајла је резервисана реч",
-    "File name contains at least one invalid character" : "Назив фајла садржи бар један недозвољен знак",
-    "File name is too long" : "Назив фајла је предугачак",
-    "Users" : "Корисници",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s је поделио „%2$s“ са Вама и жели да дода:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s је поделио „%2$s“ са Вама и жели да дода",
-    "»%s« added a note to a file shared with you" : "\"%s\" је додао белешку на фајл који дели са Вама",
-    "Open »%s«" : "Отвори „%s“",
-    "%1$s shared »%2$s« with you" : "%1$s је поделио „%2$s“ са Вама",
-    "%1$s shared »%2$s« with you." : "%1$s је поделио „%2$s“ са Вама.",
-    "Click the button below to open it." : "Кликните дугме испод да га отворите.",
-    "File is currently busy, please try again later" : "Фајл је тренутно заузет, покушајте поново касније",
-    "Cannot download file" : "Фајл не може да се преузме",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Уверите се да фајл \".ocdata\" постоји у корену директоријума са подацима."
+    "Organisation" : "Организација",
+    "Login is too long" : "Име за пријаву је сувише дугачко",
+    "Cannot write into \"apps\" directory." : "Не може да се упише у „apps” директоријум.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Ово обично може да се поправи тако што се веб серверу дозволи право уписа у apps директоријум или тако што се искључи Продавница апликација у config фајлу.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> је постављено на <code>%s</code> уместо на очекивану вредност <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Да бисте исправили овај проблем, поставите <code>mbstring.func_overload</code> на <code>0</code> у свом php.ini фајлу."
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
