@@ -9,11 +9,14 @@ namespace OC\AppFramework\Middleware;
 
 use OC\AppFramework\Utility\ControllerMethodReflector;
 use OC\Core\Controller\ClientFlowLoginV2Controller;
+use OC\Core\Controller\TwoFactorChallengeController;
 use OCP\AppFramework\Controller;
 use OCP\AppFramework\Http\Attribute\PublicPage;
 use OCP\AppFramework\Middleware;
+use OCP\Authentication\TwoFactorAuth\ALoginSetupController;
 use OCP\ISession;
 use OCP\IUserSession;
+use Psr\Log\LoggerInterface;
 use ReflectionMethod;
 
 // Will close the session if the user session is ephemeral.
@@ -23,6 +26,7 @@ class FlowV2EphemeralSessionsMiddleware extends Middleware {
 		private ISession $session,
 		private IUserSession $userSession,
 		private ControllerMethodReflector $reflector,
+		private LoggerInterface $logger,
 	) {
 	}
 
@@ -32,12 +36,17 @@ class FlowV2EphemeralSessionsMiddleware extends Middleware {
 		}
 
 		if (
-			$controller instanceof ClientFlowLoginV2Controller &&
-			($methodName === 'grantPage' || $methodName === 'generateAppPassword')
+			$controller instanceof ClientFlowLoginV2Controller
+			&& ($methodName === 'grantPage' || $methodName === 'generateAppPassword')
 		) {
 			return;
 		}
 
+		if ($controller instanceof TwoFactorChallengeController
+			|| $controller instanceof ALoginSetupController) {
+			return;
+		}
+
 		$reflectionMethod = new ReflectionMethod($controller, $methodName);
 		if (!empty($reflectionMethod->getAttributes(PublicPage::class))) {
 			return;
@@ -47,6 +56,10 @@ class FlowV2EphemeralSessionsMiddleware extends Middleware {
 			return;
 		}
 
+		$this->logger->info('Closing user and PHP session for ephemeral session', [
+			'controller' => $controller::class,
+			'method' => $methodName,
+		]);
 		$this->userSession->logout();
 		$this->session->close();
 	}
