@@ -10,27 +10,26 @@ declare(strict_types=1);
 namespace OC\OCM\Model;
 
 use NCU\Security\Signature\Model\Signatory;
-use OCP\EventDispatcher\IEventDispatcher;
-use OCP\OCM\Events\ResourceTypeRegisterEvent;
 use OCP\OCM\Exceptions\OCMArgumentException;
 use OCP\OCM\Exceptions\OCMProviderException;
-use OCP\OCM\IOCMProvider;
+use OCP\OCM\ICapabilityAwareOCMProvider;
 use OCP\OCM\IOCMResource;
 
 /**
  * @since 28.0.0
  */
-class OCMProvider implements IOCMProvider {
+class OCMProvider implements ICapabilityAwareOCMProvider {
 	private bool $enabled = false;
 	private string $apiVersion = '';
+	private string $inviteAcceptDialog = '';
+	private array $capabilities = [];
 	private string $endPoint = '';
 	/** @var IOCMResource[] */
 	private array $resourceTypes = [];
 	private ?Signatory $signatory = null;
-	private bool $emittedEvent = false;
 
 	public function __construct(
-		protected IEventDispatcher $dispatcher,
+		private readonly string $provider = '',
 	) {
 	}
 
@@ -70,6 +69,30 @@ class OCMProvider implements IOCMProvider {
 		return $this->apiVersion;
 	}
 
+	/**
+	 * returns the invite accept dialog
+	 *
+	 * @return string
+	 * @since 32.0.0
+	 */
+	public function getInviteAcceptDialog(): string {
+		return $this->inviteAcceptDialog;
+	}
+
+	/**
+	 * set the invite accept dialog
+	 *
+	 * @param string $inviteAcceptDialog
+	 *
+	 * @return $this
+	 * @since 32.0.0
+	 */
+	public function setInviteAcceptDialog(string $inviteAcceptDialog): static {
+		$this->inviteAcceptDialog = $inviteAcceptDialog;
+
+		return $this;
+	}
+
 	/**
 	 * @param string $endPoint
 	 *
@@ -88,6 +111,34 @@ class OCMProvider implements IOCMProvider {
 		return $this->endPoint;
 	}
 
+	/**
+	 * @return string
+	 */
+	public function getProvider(): string {
+		return $this->provider;
+	}
+
+	/**
+	 * @param array $capabilities
+	 *
+	 * @return $this
+	 */
+	public function setCapabilities(array $capabilities): static {
+		foreach ($capabilities as $value) {
+			if (!in_array($value, $this->capabilities)) {
+				array_push($this->capabilities, $value);
+			}
+		}
+
+		return $this;
+	}
+
+	/**
+	 * @return array
+	 */
+	public function getCapabilities(): array {
+		return $this->capabilities;
+	}
 	/**
 	 * create a new resource to later add it with {@see IOCMProvider::addResourceType()}
 	 * @return IOCMResource
@@ -122,12 +173,6 @@ class OCMProvider implements IOCMProvider {
 	 * @return IOCMResource[]
 	 */
 	public function getResourceTypes(): array {
-		if (!$this->emittedEvent) {
-			$this->emittedEvent = true;
-			$event = new ResourceTypeRegisterEvent($this);
-			$this->dispatcher->dispatchTyped($event);
-		}
-
 		return $this->resourceTypes;
 	}
 
@@ -166,9 +211,8 @@ class OCMProvider implements IOCMProvider {
 	 *
 	 * @param array $data
 	 *
-	 * @return $this
+	 * @return OCMProvider&static
 	 * @throws OCMProviderException in case a descent provider cannot be generated from data
-	 * @see self::jsonSerialize()
 	 */
 	public function import(array $data): static {
 		$this->setEnabled(is_bool($data['enabled'] ?? '') ? $data['enabled'] : false)
@@ -182,6 +226,7 @@ class OCMProvider implements IOCMProvider {
 			$resources[] = $resource->import($resourceData);
 		}
 		$this->setResourceTypes($resources);
+		$this->setInviteAcceptDialog($data['inviteAcceptDialog'] ?? '');
 
 		if (isset($data['publicKey'])) {
 			// import details about the remote request signing public key, if available
@@ -209,21 +254,7 @@ class OCMProvider implements IOCMProvider {
 	}
 
 	/**
-	 * @return array{
-	 *      enabled: bool,
-	 *      apiVersion: '1.0-proposal1',
-	 *      endPoint: string,
-	 *      publicKey?: array{
-	 *          keyId: string,
-	 *          publicKeyPem: string
-	 *      },
-	 *      resourceTypes: list<array{
-	 *          name: string,
-	 *          shareTypes: list<string>,
-	 *          protocols: array<string, string>
-	 *      }>,
-	 *      version: string
-	 *  }
+	 * @since 28.0.0
 	 */
 	public function jsonSerialize(): array {
 		$resourceTypes = [];
@@ -231,7 +262,7 @@ class OCMProvider implements IOCMProvider {
 			$resourceTypes[] = $res->jsonSerialize();
 		}
 
-		return [
+		$response = [
 			'enabled' => $this->isEnabled(),
 			'apiVersion' => '1.0-proposal1', // deprecated, but keep it to stay compatible with old version
 			'version' => $this->getApiVersion(), // informative but real version
@@ -239,5 +270,16 @@ class OCMProvider implements IOCMProvider {
 			'publicKey' => $this->getSignatory()?->jsonSerialize(),
 			'resourceTypes' => $resourceTypes
 		];
+
+		$capabilities = $this->getCapabilities();
+		if ($capabilities) {
+			$response['capabilities'] = $capabilities;
+		}
+		$inviteAcceptDialog = $this->getInviteAcceptDialog();
+		if ($inviteAcceptDialog !== '') {
+			$response['inviteAcceptDialog'] = $inviteAcceptDialog;
+		}
+		return $response;
+
 	}
 }
