@@ -21,8 +21,10 @@ use OCP\Files\SimpleFS\ISimpleFile;
 use OCP\IBinaryFinder;
 use OCP\IConfig;
 use OCP\IPreview;
-use OCP\IServerContainer;
 use OCP\Preview\IProviderV2;
+use Psr\Container\ContainerInterface;
+use Psr\Log\LoggerInterface;
+
 use function array_key_exists;
 
 class PreviewManager implements IPreview {
@@ -47,7 +49,7 @@ class PreviewManager implements IPreview {
 	 * @psalm-var array<string, null>
 	 */
 	private array $loadedBootstrapProviders = [];
-	private IServerContainer $container;
+	private ContainerInterface $container;
 	private IBinaryFinder $binaryFinder;
 	private IMagickSupport $imagickSupport;
 	private bool $enablePreviews;
@@ -60,7 +62,7 @@ class PreviewManager implements IPreview {
 		GeneratorHelper $helper,
 		?string $userId,
 		Coordinator $bootstrapCoordinator,
-		IServerContainer $container,
+		ContainerInterface $container,
 		IBinaryFinder $binaryFinder,
 		IMagickSupport $imagickSupport,
 	) {
@@ -136,35 +138,27 @@ class PreviewManager implements IPreview {
 					$this->rootFolder,
 					$this->config
 				),
-				$this->eventDispatcher
+				$this->eventDispatcher,
+				$this->container->get(LoggerInterface::class),
 			);
 		}
 		return $this->generator;
 	}
 
-	/**
-	 * Returns a preview of a file
-	 *
-	 * The cache is searched first and if nothing usable was found then a preview is
-	 * generated by one of the providers
-	 *
-	 * @param File $file
-	 * @param int $width
-	 * @param int $height
-	 * @param bool $crop
-	 * @param string $mode
-	 * @param string $mimeType
-	 * @return ISimpleFile
-	 * @throws NotFoundException
-	 * @throws \InvalidArgumentException if the preview would be invalid (in case the original image is invalid)
-	 * @since 11.0.0 - \InvalidArgumentException was added in 12.0.0
-	 */
-	public function getPreview(File $file, $width = -1, $height = -1, $crop = false, $mode = IPreview::MODE_FILL, $mimeType = null) {
-		$this->throwIfPreviewsDisabled();
+	public function getPreview(
+		File $file,
+		$width = -1,
+		$height = -1,
+		$crop = false,
+		$mode = IPreview::MODE_FILL,
+		$mimeType = null,
+		bool $cacheResult = true,
+	): ISimpleFile {
+		$this->throwIfPreviewsDisabled($file, $mimeType);
 		$previewConcurrency = $this->getGenerator()->getNumConcurrentPreviews('preview_concurrency_all');
 		$sem = Generator::guardWithSemaphore(Generator::SEMAPHORE_ID_ALL, $previewConcurrency);
 		try {
-			$preview = $this->getGenerator()->getPreview($file, $width, $height, $crop, $mode, $mimeType);
+			$preview = $this->getGenerator()->getPreview($file, $width, $height, $crop, $mode, $mimeType, $cacheResult);
 		} finally {
 			Generator::unguardWithSemaphore($sem);
 		}
@@ -184,7 +178,7 @@ class PreviewManager implements IPreview {
 	 * @since 19.0.0
 	 */
 	public function generatePreviews(File $file, array $specifications, $mimeType = null) {
-		$this->throwIfPreviewsDisabled();
+		$this->throwIfPreviewsDisabled($file, $mimeType);
 		return $this->getGenerator()->generatePreviews($file, $specifications, $mimeType);
 	}
 
@@ -219,13 +213,15 @@ class PreviewManager implements IPreview {
 	/**
 	 * Check if a preview can be generated for a file
 	 */
-	public function isAvailable(\OCP\Files\FileInfo $file): bool {
+	public function isAvailable(\OCP\Files\FileInfo $file, ?string $mimeType = null): bool {
 		if (!$this->enablePreviews) {
 			return false;
 		}
 
+		$fileMimeType = $mimeType ?? $file->getMimeType();
+
 		$this->registerCoreProviders();
-		if (!$this->isMimeSupported($file->getMimetype())) {
+		if (!$this->isMimeSupported($fileMimeType)) {
 			return false;
 		}
 
@@ -235,7 +231,7 @@ class PreviewManager implements IPreview {
 		}
 
 		foreach ($this->providers as $supportedMimeType => $providers) {
-			if (preg_match($supportedMimeType, $file->getMimetype())) {
+			if (preg_match($supportedMimeType, $fileMimeType)) {
 				foreach ($providers as $providerClosure) {
 					$provider = $this->helper->getProvider($providerClosure);
 					if (!($provider instanceof IProviderV2)) {
@@ -255,29 +251,29 @@ class PreviewManager implements IPreview {
 	 * List of enabled default providers
 	 *
 	 * The following providers are enabled by default:
-	 *  - OC\Preview\PNG
-	 *  - OC\Preview\JPEG
-	 *  - OC\Preview\GIF
 	 *  - OC\Preview\BMP
-	 *  - OC\Preview\XBitmap
+	 *  - OC\Preview\GIF
+	 *  - OC\Preview\JPEG
 	 *  - OC\Preview\MarkDown
-	 *  - OC\Preview\MP3
+	 *  - OC\Preview\PNG
 	 *  - OC\Preview\TXT
+	 *  - OC\Preview\XBitmap
 	 *
 	 * The following providers are disabled by default due to performance or privacy concerns:
 	 *  - OC\Preview\Font
 	 *  - OC\Preview\HEIC
 	 *  - OC\Preview\Illustrator
-	 *  - OC\Preview\Movie
-	 *  - OC\Preview\MSOfficeDoc
+	 *  - OC\Preview\MP3
 	 *  - OC\Preview\MSOffice2003
 	 *  - OC\Preview\MSOffice2007
+	 *  - OC\Preview\MSOfficeDoc
+	 *  - OC\Preview\Movie
 	 *  - OC\Preview\OpenDocument
 	 *  - OC\Preview\PDF
 	 *  - OC\Preview\Photoshop
 	 *  - OC\Preview\Postscript
-	 *  - OC\Preview\StarOffice
 	 *  - OC\Preview\SVG
+	 *  - OC\Preview\StarOffice
 	 *  - OC\Preview\TIFF
 	 *
 	 * @return array
@@ -299,7 +295,6 @@ class PreviewManager implements IPreview {
 
 		$this->defaultProviders = $this->config->getSystemValue('enabledPreviewProviders', array_merge([
 			Preview\MarkDown::class,
-			Preview\MP3::class,
 			Preview\TXT::class,
 			Preview\OpenDocument::class,
 		], $imageProviders));
@@ -377,14 +372,11 @@ class PreviewManager implements IPreview {
 
 		$this->registerCoreProvidersOffice();
 
-		// Video requires avconv or ffmpeg
+		// Video requires ffmpeg
 		if (in_array(Preview\Movie::class, $this->getEnabledDefaultProvider())) {
 			$movieBinary = $this->config->getSystemValue('preview_ffmpeg_path', null);
 			if (!is_string($movieBinary)) {
-				$movieBinary = $this->binaryFinder->findBinaryPath('avconv');
-				if (!is_string($movieBinary)) {
-					$movieBinary = $this->binaryFinder->findBinaryPath('ffmpeg');
-				}
+				$movieBinary = $this->binaryFinder->findBinaryPath('ffmpeg');
 			}
 
 
@@ -461,8 +453,8 @@ class PreviewManager implements IPreview {
 	/**
 	 * @throws NotFoundException if preview generation is disabled
 	 */
-	private function throwIfPreviewsDisabled(): void {
-		if (!$this->enablePreviews) {
+	private function throwIfPreviewsDisabled(File $file, ?string $mimeType = null): void {
+		if (!$this->isAvailable($file, $mimeType)) {
 			throw new NotFoundException('Previews disabled');
 		}
 	}
